#
import pytest
from load_one_data import dump_diff, one_dump_test  # , dump_same_and_not_same

from ArWikiCats import resolve_arabic_category_label

data_virginia_1 = {
    "Category:Baseball in West Virginia": "تصنيف:كرة القاعدة في فرجينيا الغربية",
    "Category:Baseball players from Alexandria, Virginia": "تصنيف:لاعبو كرة قاعدة من الإسكندرية (فرجينيا)",
    "Category:Baseball players from Danville, Virginia": "تصنيف:لاعبو كرة قاعدة من دانفيل (فرجينيا)",
    "Category:Baseball players from Fredericksburg, Virginia": "تصنيف:لاعبو كرة قاعدة من فريدريكسبيورغ (فرجينيا)",
    "Category:Baseball players from Harrisonburg, Virginia": "تصنيف:لاعبو كرة قاعدة من هاريسونبورغ (فرجينيا)",
    "Category:Baseball players from Huntington, West Virginia": "تصنيف:لاعبو كرة قاعدة من هنغتينغتون (فرجينيا الغربية)",
}

data_virginia_2 = {
    "Category:1778 establishments in Virginia": "تصنيف:تأسيسات سنة 1778 في فرجينيا",
    "Category:1781 in Virginia": "تصنيف:فرجينيا في 1781",
    "Category:1819 establishments in Virginia": "تصنيف:تأسيسات سنة 1819 في فرجينيا",
    "Category:1824 establishments in Virginia": "تصنيف:تأسيسات سنة 1824 في فرجينيا",
    "Category:1824 in Virginia": "تصنيف:فرجينيا في 1824",
    "Category:1831 establishments in Virginia": "تصنيف:تأسيسات سنة 1831 في فرجينيا",
    "Category:1836 establishments in Virginia": "تصنيف:تأسيسات سنة 1836 في فرجينيا",
    "Category:1845 establishments in Virginia": "تصنيف:تأسيسات سنة 1845 في فرجينيا",
    "Category:1861 establishments in Virginia": "تصنيف:تأسيسات سنة 1861 في فرجينيا",
    "Category:1869 establishments in West Virginia": "تصنيف:تأسيسات سنة 1869 في فرجينيا الغربية",
    "Category:1869 in West Virginia": "تصنيف:فرجينيا الغربية في 1869",
    "Category:1870 establishments in West Virginia": "تصنيف:تأسيسات سنة 1870 في فرجينيا الغربية",
    "Category:1870 in West Virginia": "تصنيف:فرجينيا الغربية في 1870",
    "Category:1872 establishments in Virginia": "تصنيف:تأسيسات سنة 1872 في فرجينيا",
    "Category:1874 establishments in West Virginia": "تصنيف:تأسيسات سنة 1874 في فرجينيا الغربية",
    "Category:1879 establishments in West Virginia": "تصنيف:تأسيسات سنة 1879 في فرجينيا الغربية",
    "Category:1880 establishments in Virginia": "تصنيف:تأسيسات سنة 1880 في فرجينيا",
    "Category:1880s disestablishments in West Virginia": "تصنيف:انحلالات عقد 1880 في فرجينيا الغربية",
    "Category:1882 establishments in West Virginia": "تصنيف:تأسيسات سنة 1882 في فرجينيا الغربية",
    "Category:1886 disestablishments in West Virginia": "تصنيف:انحلالات سنة 1886 في فرجينيا الغربية",
    "Category:1886 in West Virginia": "تصنيف:فرجينيا الغربية في 1886",
    "Category:1887 in West Virginia": "تصنيف:فرجينيا الغربية في 1887",
    "Category:1888 establishments in West Virginia": "تصنيف:تأسيسات سنة 1888 في فرجينيا الغربية",
    "Category:1888 in West Virginia": "تصنيف:فرجينيا الغربية في 1888",
    "Category:1890 establishments in West Virginia": "تصنيف:تأسيسات سنة 1890 في فرجينيا الغربية",
    "Category:1890 in West Virginia": "تصنيف:فرجينيا الغربية في 1890",
    "Category:1891 establishments in West Virginia": "تصنيف:تأسيسات سنة 1891 في فرجينيا الغربية",
    "Category:1892 establishments in West Virginia": "تصنيف:تأسيسات سنة 1892 في فرجينيا الغربية",
    "Category:1892 in West Virginia": "تصنيف:فرجينيا الغربية في 1892",
    "Category:1894 establishments in West Virginia": "تصنيف:تأسيسات سنة 1894 في فرجينيا الغربية",
    "Category:1894 in West Virginia": "تصنيف:فرجينيا الغربية في 1894",
    "Category:1896 establishments in West Virginia": "تصنيف:تأسيسات سنة 1896 في فرجينيا الغربية",
    "Category:1897 establishments in West Virginia": "تصنيف:تأسيسات سنة 1897 في فرجينيا الغربية",
    "Category:1897 in West Virginia": "تصنيف:فرجينيا الغربية في 1897",
    "Category:1905 establishments in West Virginia": "تصنيف:تأسيسات سنة 1905 في فرجينيا الغربية",
    "Category:1906 establishments in Virginia": "تصنيف:تأسيسات سنة 1906 في فرجينيا",
    "Category:1906 establishments in West Virginia": "تصنيف:تأسيسات سنة 1906 في فرجينيا الغربية",
    "Category:1916 establishments in West Virginia": "تصنيف:تأسيسات سنة 1916 في فرجينيا الغربية",
    "Category:1920s establishments in West Virginia": "تصنيف:تأسيسات عقد 1920 في فرجينيا الغربية",
    "Category:1921 establishments in West Virginia": "تصنيف:تأسيسات سنة 1921 في فرجينيا الغربية",
    "Category:1924 establishments in Virginia": "تصنيف:تأسيسات سنة 1924 في فرجينيا",
    "Category:1940 in Virginia": "تصنيف:فرجينيا في 1940",
    "Category:1949 in Virginia": "تصنيف:فرجينيا في 1949",
    "Category:1950s establishments in West Virginia": "تصنيف:تأسيسات عقد 1950 في فرجينيا الغربية",
    "Category:1960s establishments in West Virginia": "تصنيف:تأسيسات عقد 1960 في فرجينيا الغربية",
    "Category:1973 establishments in Virginia": "تصنيف:تأسيسات سنة 1973 في فرجينيا",
    "Category:1978 establishments in West Virginia": "تصنيف:تأسيسات سنة 1978 في فرجينيا الغربية",
    "Category:1992 establishments in Virginia": "تصنيف:تأسيسات سنة 1992 في فرجينيا",
    "Category:19th-century disestablishments in West Virginia": "تصنيف:انحلالات القرن 19 في فرجينيا الغربية",
    "Category:19th-century mayors of places in West Virginia": "تصنيف:رؤساء بلديات في فرجينيا الغربية في القرن 19",
    "Category:19th-century members of the West Virginia Legislature": "تصنيف:أعضاء هيئة فرجينيا الغربية التشريعية في القرن 19",
    "Category:19th-century people from West Virginia": "تصنيف:أشخاص من فرجينيا الغربية في القرن 19",
    "Category:19th-century West Virginia politicians": "تصنيف:سياسيو فرجينيا الغربية في القرن 19",
    "Category:2007 establishments in Virginia": "تصنيف:تأسيسات سنة 2007 في فرجينيا",
    "Category:2010s disestablishments in West Virginia": "تصنيف:انحلالات عقد 2010 في فرجينيا الغربية",
    "Category:2012 in Virginia": "تصنيف:فرجينيا في 2012",
    "Category:2017 disestablishments in West Virginia": "تصنيف:انحلالات سنة 2017 في فرجينيا الغربية",
    "Category:2020s disestablishments in West Virginia": "تصنيف:انحلالات عقد 2020 في فرجينيا الغربية",
    "Category:2022 disestablishments in West Virginia": "تصنيف:انحلالات سنة 2022 في فرجينيا الغربية",
    "Category:20th-century mayors of places in West Virginia": "تصنيف:رؤساء بلديات في فرجينيا الغربية في القرن 20",
    "Category:20th-century members of the West Virginia Legislature": "تصنيف:أعضاء هيئة فرجينيا الغربية التشريعية في القرن 20",
    "Category:20th-century people from West Virginia": "تصنيف:أشخاص من فرجينيا الغربية في القرن 20",
    "Category:20th-century West Virginia politicians": "تصنيف:سياسيو فرجينيا الغربية في القرن 20",
    "Category:21st-century disestablishments in West Virginia": "تصنيف:انحلالات القرن 21 في فرجينيا الغربية",
    "Category:21st-century establishments in West Virginia": "تصنيف:تأسيسات القرن 21 في فرجينيا الغربية",
    "Category:21st-century members of the West Virginia Legislature": "تصنيف:أعضاء هيئة فرجينيا الغربية التشريعية في القرن 21",
    "Category:21st-century people from West Virginia": "تصنيف:أشخاص من فرجينيا الغربية في القرن 21",
    "Category:21st-century West Virginia politicians": "تصنيف:سياسيو فرجينيا الغربية في القرن 21",
    "Category:3rd-millennium disestablishments in West Virginia": "تصنيف:انحلالات الألفية 3 في فرجينيا الغربية",
    "Category:3rd-millennium establishments in West Virginia": "تصنيف:تأسيسات الألفية 3 في فرجينيا الغربية",
    "Category:Academics from Bluefield, West Virginia": "تصنيف:أكاديميون من بلوفيلد (فرجينيا الغربية)",
    "Category:Accomack County, Virginia": "تصنيف:مقاطعة أكوماك (فرجينيا)",
    "Category:Actors from Fairfax, Virginia": "تصنيف:ممثلون من فيرفاكس (فرجينيا)",
    "Category:Actors from Monongalia County, West Virginia": "تصنيف:ممثلون من مقاطعة مونونغاليا (فرجينيا الغربية)",
    "Category:Actors from Tucker County, West Virginia": "تصنيف:ممثلون من مقاطعة تاكر (فرجينيا الغربية)",
    "Category:Actresses from Alexandria, Virginia": "تصنيف:ممثلات من الإسكندرية (فرجينيا)",
    "Category:Actresses from Charleston, West Virginia": "تصنيف:ممثلات من تشارلستون (فرجينيا الغربية)",
    "Category:Actresses from Fairfax, Virginia": "تصنيف:ممثلات من فيرفاكس (فرجينيا)",
    "Category:African-American history of West Virginia": "تصنيف:تاريخ أمريكي إفريقي في فرجينيا الغربية",
    "Category:African-American state legislators in West Virginia": "تصنيف:مشرعو الولايات أمريكيون أفارقة في فرجينيا الغربية",
    "Category:Airliner accidents and incidents in West Virginia": "تصنيف:حوادث طائرات في فرجينيا الغربية",
    "Category:Albemarle County, Virginia": "تصنيف:مقاطعة ألبمارل (فرجينيا)",
    "Category:Alderson, West Virginia": "تصنيف:ألدرسن (فرجينيا الغربية)",
    "Category:Alexandria, Virginia": "تصنيف:الإسكندرية (فرجينيا)",
    "Category:Alleghany County, Virginia": "تصنيف:مقاطعة أليغاني (فرجينيا)",
    "Category:Amelia County, Virginia": "تصنيف:مقاطعة أميليا (فرجينيا)",
    "Category:Amherst County, Virginia": "تصنيف:مقاطعة أمهيرست (فرجينيا)",
    "Category:Ansted, West Virginia": "تصنيف:أنستيد (فرجينيا الغربية)",
    "Category:Appomattox County, Virginia": "تصنيف:مقاطعة أبوماتوكس (فرجينيا)",
    "Category:Architects from Charleston, West Virginia": "تصنيف:معماريون من تشارلستون (فرجينيا الغربية)",
    "Category:Architects from Wheeling, West Virginia": "تصنيف:معماريون من ويلينغ (فرجينيا الغربية)",
    "Category:Arlington County, Virginia": "تصنيف:مقاطعة أرلنغتون (فرجينيا)",
    "Category:Artists from Alexandria, Virginia": "تصنيف:فنانون من الإسكندرية (فرجينيا)",
    "Category:Artists from Charleston, West Virginia": "تصنيف:فنانون من تشارلستون (فرجينيا الغربية)",
    "Category:Artists from Roanoke, Virginia": "تصنيف:فنانون من روانوك (فرجينيا)",
    "Category:Artists from West Virginia by populated place": "تصنيف:فنانون من فرجينيا الغربية حسب المكان المأهول",
    "Category:Artists from Wheeling, West Virginia": "تصنيف:فنانون من ويلينغ (فرجينيا الغربية)",
    "Category:Athens, West Virginia": "تصنيف:أثينا (فرجينيا الغربية)",
    "Category:Augusta County, Virginia": "تصنيف:مقاطعة أوغوستا (فرجينيا)",
    "Category:Aviation accidents and incidents in West Virginia": "تصنيف:حوادث طيران في فرجينيا الغربية",
    "Category:Baseball coaches from West Virginia": "تصنيف:مدربو كرة قاعدة من فرجينيا الغربية",
    "Category:Baseball in West Virginia": "تصنيف:كرة القاعدة في فرجينيا الغربية",
    "Category:Baseball players from Alexandria, Virginia": "تصنيف:لاعبو كرة قاعدة من الإسكندرية (فرجينيا)",
    "Category:Baseball players from Danville, Virginia": "تصنيف:لاعبو كرة قاعدة من دانفيل (فرجينيا)",
    "Category:Baseball players from Fredericksburg, Virginia": "تصنيف:لاعبو كرة قاعدة من فريدريكسبيورغ (فرجينيا)",
    "Category:Baseball players from Harrisonburg, Virginia": "تصنيف:لاعبو كرة قاعدة من هاريسونبورغ (فرجينيا)",
    "Category:Baseball players from Huntington, West Virginia": "تصنيف:لاعبو كرة قاعدة من هنغتينغتون (فرجينيا الغربية)",
    "Category:Baseball players from Lynchburg, Virginia": "تصنيف:لاعبو كرة قاعدة من لينشبرغ (فرجينيا)",
    "Category:Baseball players from Portsmouth, Virginia": "تصنيف:لاعبو كرة قاعدة من بورتسموث (فرجينيا)",
    "Category:Baseball players from Prince Edward County, Virginia": "تصنيف:لاعبو كرة قاعدة من مقاطعة برينس إدورد (فرجينيا)",
    "Category:Baseball players from Staunton, Virginia": "تصنيف:لاعبو كرة قاعدة من ستونتون (فرجينيا)",
    "Category:Baseball players from Wheeling, West Virginia": "تصنيف:لاعبو كرة قاعدة من ويلينغ (فرجينيا الغربية)",
    "Category:Baseball players from Williamsburg, Virginia": "تصنيف:لاعبو كرة قاعدة من ويليامزبرغ (فرجينيا)",
    "Category:Baseball players in Lynchburg, Virginia by team": "تصنيف:لاعبو كرة قاعدة في لينشبرغ (فرجينيا) حسب الفريق",
    "Category:Basketball in West Virginia": "تصنيف:كرة السلة في فرجينيا الغربية",
    "Category:Basketball players from Alexandria, Virginia": "تصنيف:لاعبو كرة سلة من الإسكندرية (فرجينيا)",
    "Category:Basketball players from Portsmouth, Virginia": "تصنيف:لاعبو كرة سلة من بورتسموث (فرجينيا)",
    "Category:Bath County, Virginia": "تصنيف:مقاطعة باث (فرجينيا)",
    "Category:Bedford County, Virginia": "تصنيف:مقاطعة بيدفورد (فرجينيا)",
    "Category:Berkeley County, West Virginia": "تصنيف:مقاطعة بيركلي (فرجينيا الغربية)",
    "Category:Bethany, West Virginia": "تصنيف:بيثاني (فرجينيا الغربية)",
    "Category:Beverly, West Virginia": "تصنيف:بيفرلي (فرجينيا الغربية)",
    "Category:Biologists from West Virginia": "تصنيف:علماء أحياء من فرجينيا الغربية",
    "Category:Bland County, Virginia": "تصنيف:مقاطعة بلاند (فرجينيا)",
    "Category:Bluegrass musicians from West Virginia": "تصنيف:موسيقيو بلوغراس من فرجينيا الغربية",
    "Category:Blues musicians from West Virginia": "تصنيف:موسيقيو بلوز من فرجينيا الغربية",
    "Category:Bodies of water of King George County, Virginia": "تصنيف:مسطحات مائية في مقاطعة كينغ جورج (فرجينيا)",
    "Category:Books about West Virginia": "تصنيف:كتب عن فرجينيا الغربية",
    "Category:Boone County, West Virginia": "تصنيف:مقاطعة بوون (فرجينيا الغربية)",
    "Category:Botetourt County, Virginia": "تصنيف:مقاطعة بوتيتورت (فرجينيا)",
    "Category:Bramwell, West Virginia": "تصنيف:برامويل (فرجينيا الغربية)",
    "Category:Braxton County, West Virginia": "تصنيف:مقاطعة براكستون (فرجينيا الغربية)",
    "Category:Bridges in Mason County, West Virginia": "تصنيف:جسور في مقاطعة ماسون (فرجينيا الغربية)",
    "Category:Bridges in West Virginia by county": "تصنيف:جسور في فرجينيا الغربية حسب المقاطعة",
    "Category:Bristol, Virginia": "تصنيف:بريستول (فرجينيا)",
    "Category:Brooke County, West Virginia": "تصنيف:مقاطعة بروك (فرجينيا الغربية)",
    "Category:Brunswick County, Virginia": "تصنيف:مقاطعة برونزويك (فرجينيا)",
    "Category:Buchanan County, Virginia": "تصنيف:مقاطعة بوكانان (فرجينيا)",
    "Category:Buckingham County, Virginia": "تصنيف:مقاطعة باكنغهام (فرجينيا)",
    "Category:Buildings and structures in Albemarle County, Virginia": "تصنيف:مبان ومنشآت في مقاطعة ألبمارل (فرجينيا)",
    "Category:Buildings and structures in Alexandria, Virginia": "تصنيف:مبان ومنشآت في الإسكندرية (فرجينيا)",
    "Category:Buildings and structures in Arlington County, Virginia": "تصنيف:مبان ومنشآت في مقاطعة أرلنغتون (فرجينيا)",
    "Category:Buildings and structures in Bluefield, West Virginia": "تصنيف:مبان ومنشآت في بلوفيلد (فرجينيا الغربية)",
    "Category:Buildings and structures in Danville, Virginia": "تصنيف:مبان ومنشآت في دانفيل (فرجينيا)",
    "Category:Buildings and structures in Fairfax County, Virginia": "تصنيف:مبان ومنشآت في مقاطعة فيرفاكس (فرجينيا)",
    "Category:Buildings and structures in Floyd County, Virginia": "تصنيف:مبان ومنشآت في مقاطعة فلويد (فرجينيا)",
    "Category:Buildings and structures in Greenbrier County, West Virginia": "تصنيف:مبان ومنشآت في مقاطعة غرينبريه (فرجينيا الغربية)",
    "Category:Buildings and structures in Hampshire County, West Virginia": "تصنيف:مبان ومنشآت في مقاطعة هامبشاير (فرجينيا الغربية)",
    "Category:Buildings and structures in Harrisonburg, Virginia": "تصنيف:مبان ومنشآت في هاريسونبورغ (فرجينيا)",
    "Category:Buildings and structures in Lexington, Virginia": "تصنيف:مبان ومنشآت في كسينغتون (فرجينيا)",
    "Category:Buildings and structures in Loudoun County, Virginia": "تصنيف:مبان ومنشآت في مقاطعة لودون (فرجينيا)",
    "Category:Buildings and structures in Parkersburg, West Virginia": "تصنيف:مبان ومنشآت في باركرسبورغ (فرجينيا الغربية)",
    "Category:Buildings and structures in Radford, Virginia": "تصنيف:مبان ومنشآت في رادفورد (فرجينيا)",
    "Category:Buildings and structures in Romney, West Virginia": "تصنيف:مبان ومنشآت في رومني (فرجينيا الغربية)",
    "Category:Buildings and structures in Tucker County, West Virginia": "تصنيف:مبان ومنشآت في مقاطعة تاكر (فرجينيا الغربية)",
    "Category:Buildings and structures in West Virginia by condition": "تصنيف:مبان ومنشآت في فرجينيا الغربية حسب الحالة",
    "Category:Buildings and structures in West Virginia by type": "تصنيف:مبان ومنشآت في فرجينيا الغربية حسب الفئة",
    "Category:Buildings and structures in Wheeling, West Virginia": "تصنيف:مبان ومنشآت في ويلينغ (فرجينيا الغربية)",
    "Category:Buildings and structures in White Sulphur Springs, West Virginia": "تصنيف:مبان ومنشآت في وايت سولفور سبرينغز (فرجينيا الغربية)",
    "Category:Buildings and structures in Williamsburg, Virginia": "تصنيف:مبان ومنشآت في ويليامزبرغ (فرجينيا)",
    "Category:Buildings and structures in York County, Virginia": "تصنيف:مبان ومنشآت في مقاطعة يورك (فرجينيا)",
    "Category:Buildings and structures on the National Register of Historic Places in West Virginia": "تصنيف:مبان ومنشآت في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "Category:Burial monuments and structures in West Virginia": "تصنيف:معالم ومنشآت أماكن الدفن في فرجينيا الغربية",
    "Category:Burnsville, West Virginia": "تصنيف:بورنسفيل (فرجينيا الغربية)",
    "Category:Businesspeople from Alexandria, Virginia": "تصنيف:شخصيات أعمال من الإسكندرية (فرجينيا)",
    "Category:Businesspeople from Beckley, West Virginia": "تصنيف:شخصيات أعمال من بيكلي (فرجينيا الغربية)",
    "Category:Businesspeople from Bluefield, West Virginia": "تصنيف:شخصيات أعمال من بلوفيلد (فرجينيا الغربية)",
    "Category:Businesspeople from Charleston, West Virginia": "تصنيف:شخصيات أعمال من تشارلستون (فرجينيا الغربية)",
    "Category:Businesspeople from Clarksburg, West Virginia": "تصنيف:شخصيات أعمال من كلاركسبورغ (فرجينيا الغربية)",
    "Category:Businesspeople from Morgantown, West Virginia": "تصنيف:شخصيات أعمال من مورغانتاون (فرجينيا الغربية)",
    "Category:Businesspeople from Parkersburg, West Virginia": "تصنيف:شخصيات أعمال من باركرسبورغ (فرجينيا الغربية)",
    "Category:Businesspeople from Romney, West Virginia": "تصنيف:شخصيات أعمال من رومني (فرجينيا الغربية)",
    "Category:Businesspeople from West Virginia by populated place": "تصنيف:شخصيات أعمال من فرجينيا الغربية حسب المكان المأهول",
    "Category:Businesspeople from Wheeling, West Virginia": "تصنيف:شخصيات أعمال من ويلينغ (فرجينيا الغربية)",
    "Category:Campbell County, Virginia": "تصنيف:مقاطعة كامبل (فرجينيا)",
    "Category:Capon Bridge, West Virginia": "تصنيف:كابون بريدج (فرجينيا الغربية)",
    "Category:Caroline County, Virginia": "تصنيف:مقاطعة كارولين (فرجينيا)",
    "Category:Carroll County, Virginia": "تصنيف:مقاطعة كارول (فرجينيا)",
    "Category:Catholics from West Virginia": "تصنيف:كاثوليك من فرجينيا الغربية",
    "Category:Cemeteries in Arlington County, Virginia": "تصنيف:مقابر في مقاطعة أرلنغتون (فرجينيا)",
    "Category:Census-designated places in Alleghany County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة أليغاني (فرجينيا)",
    "Category:Census-designated places in Augusta County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة أوغوستا (فرجينيا)",
    "Category:Census-designated places in Bedford County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة بيدفورد (فرجينيا)",
    "Category:Census-designated places in Botetourt County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة بوتيتورت (فرجينيا)",
    "Category:Census-designated places in Brooke County, West Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة بروك (فرجينيا الغربية)",
    "Category:Census-designated places in Carroll County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة كارول (فرجينيا)",
    "Category:Census-designated places in Chesterfield County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة تشيسترفيلد (فرجينيا)",
    "Category:Census-designated places in Fairfax County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة فيرفاكس (فرجينيا)",
    "Category:Census-designated places in Franklin County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة فرانكلين (فرجينيا)",
    "Category:Census-designated places in Gloucester County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة غلوستر (فرجينيا)",
    "Category:Census-designated places in Henrico County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة هنريكو (فرجينيا)",
    "Category:Census-designated places in Isle of Wight County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة آيل أوف وايت (فرجينيا)",
    "Category:Census-designated places in King George County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة كينغ جورج (فرجينيا)",
    "Category:Census-designated places in Lee County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة لي (فرجينيا)",
    "Category:Census-designated places in Patrick County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة باتريك (فرجينيا)",
    "Category:Census-designated places in Prince Edward County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة برينس إدورد (فرجينيا)",
    "Category:Census-designated places in Prince William County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة برينس ويليام (فرجينيا)",
    "Category:Census-designated places in Roanoke County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة رونوك (فرجينيا)",
    "Category:Census-designated places in Russell County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة روسيل (فرجينيا)",
    "Category:Census-designated places in Smyth County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة سميث (فرجينيا)",
    "Category:Census-designated places in Spotsylvania County, Virginia": "تصنيف:مناطق إحصاء سكاني في مقاطعة سبوتسيلفانيا (فرجينيا)",
    "Category:Charles City County, Virginia": "تصنيف:مقاطعة تشارلز سيتي (فرجينيا)",
    "Category:Charlotte County, Virginia": "تصنيف:مقاطعة شارلوت (فرجينيا)",
    "Category:Chemists from West Virginia": "تصنيف:كيميائيون من فرجينيا الغربية",
    "Category:Chesterfield County, Virginia": "تصنيف:مقاطعة تشيسترفيلد (فرجينيا)",
    "Category:Cities in Fayette County, West Virginia": "تصنيف:مدن في مقاطعة فيات (فرجينيا الغربية)",
    "Category:Civil servants from Bluefield, West Virginia": "تصنيف:موظفو خدمة مدنية من بلوفيلد (فرجينيا الغربية)",
    "Category:Civil servants from Charleston, West Virginia": "تصنيف:موظفو خدمة مدنية من تشارلستون (فرجينيا الغربية)",
    "Category:Civil servants from Romney, West Virginia": "تصنيف:موظفو خدمة مدنية من رومني (فرجينيا الغربية)",
    "Category:Civil servants from West Virginia": "تصنيف:موظفو خدمة مدنية من فرجينيا الغربية",
    "Category:Clarke County, Virginia": "تصنيف:مقاطعة كلارك (فرجينيا)",
    "Category:Clergy from West Virginia": "تصنيف:رجال دين من فرجينيا الغربية",
    "Category:Clifton, Virginia": "تصنيف:كليفتون (فرجينيا)",
    "Category:Clubhouses in West Virginia": "تصنيف:نوادي في فرجينيا الغربية",
    "Category:Clubhouses on the National Register of Historic Places in West Virginia": "تصنيف:نوادي في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "Category:Companies based in Fairfax, Virginia": "تصنيف:شركات مقرها في فيرفاكس (فرجينيا)",
    "Category:Companies based in Fairfax County, Virginia": "تصنيف:شركات مقرها في مقاطعة فيرفاكس (فرجينيا)",
    "Category:Companies based in Reston, Virginia": "تصنيف:شركات مقرها في رستون (فرجينيا)",
    "Category:Congressional delegations from West Virginia navigational boxes": "تصنيف:صناديق تصفح وفود الكونغرس من فرجينيا الغربية",
    "Category:County clerks in West Virginia": "تصنيف:كاتبو مقاطعات في فرجينيا الغربية",
    "Category:County commissioners in West Virginia": "تصنيف:مفوضو مقاطعات في فرجينيا الغربية",
    "Category:Covington, Virginia": "تصنيف:كوفينغتون (فرجينيا)",
    "Category:Craig County, Virginia": "تصنيف:مقاطعة كريغ (فرجينيا)",
    "Category:Culpeper County, Virginia": "تصنيف:مقاطعة كلبيبر (فرجينيا)",
    "Category:Cultural organizations based in West Virginia": "تصنيف:منظمات ثقافية مقرها في فرجينيا الغربية",
    "Category:Culture of Beckley, West Virginia": "تصنيف:ثقافة بيكلي (فرجينيا الغربية)",
    "Category:Culture of Bluefield, West Virginia": "تصنيف:ثقافة بلوفيلد (فرجينيا الغربية)",
    "Category:Culture of Clarksburg, West Virginia": "تصنيف:ثقافة كلاركسبورغ (فرجينيا الغربية)",
    "Category:Culture of Elkins, West Virginia": "تصنيف:ثقافة إلكينز (فرجينيا الغربية)",
    "Category:Culture of Martinsburg, West Virginia": "تصنيف:ثقافة مرتينسبورغ (فرجينيا الغربية)",
    "Category:Culture of Parkersburg, West Virginia": "تصنيف:ثقافة باركرسبورغ (فرجينيا الغربية)",
    "Category:Cumberland County, Virginia": "تصنيف:مقاطعة كومبرلاند (فرجينيا)",
    "Category:Danville, Virginia": "تصنيف:دانفيل (فرجينيا)",
    "Category:Deaths from brain cancer in West Virginia": "تصنيف:وفيات سرطان الدماغ في فرجينيا الغربية",
    "Category:Deaths in West Virginia": "تصنيف:وفيات في فرجينيا الغربية",
    "Category:Defunct organizations based in West Virginia": "تصنيف:منظمات سابقة مقرها في فرجينيا الغربية",
    "Category:Defunct schools in West Virginia": "تصنيف:مدارس سابقة في فرجينيا الغربية",
    "Category:Defunct universities and colleges in West Virginia": "تصنيف:جامعات وكليات سابقة في فرجينيا الغربية",
    "Category:Democratic Party United States senators from West Virginia": "تصنيف:أعضاء مجلس الشيوخ الأمريكي من الحزب الديمقراطي من فرجينيا الغربية",
    "Category:Demographics of West Virginia": "تصنيف:التركيبة السكانية في فرجينيا الغربية",
    "Category:Demolished buildings and structures in West Virginia": "تصنيف:مبان ومنشآت مهدمة في فرجينيا الغربية",
    "Category:Dickenson County, Virginia": "تصنيف:مقاطعة ديكينسون (فرجينيا)",
    "Category:Dinwiddie County, Virginia": "تصنيف:مقاطعة دينويدي (فرجينيا)",
    "Category:Disasters in Virginia": "تصنيف:كوارث في فرجينيا",
    "Category:Drummers from West Virginia": "تصنيف:طبالون من فرجينيا الغربية",
    "Category:Economy of Alexandria, Virginia": "تصنيف:اقتصاد الإسكندرية (فرجينيا)",
    "Category:Education in Albemarle County, Virginia": "تصنيف:التعليم في مقاطعة ألبمارل (فرجينيا)",
    "Category:Education in Arlington County, Virginia": "تصنيف:التعليم في مقاطعة أرلنغتون (فرجينيا)",
    "Category:Education in Berkeley County, West Virginia": "تصنيف:التعليم في مقاطعة بيركلي (فرجينيا الغربية)",
    "Category:Education in Danville, Virginia": "تصنيف:التعليم في دانفيل (فرجينيا)",
    "Category:Education in Fairfax County, Virginia": "تصنيف:التعليم في مقاطعة فيرفاكس (فرجينيا)",
    "Category:Education in Greenbrier County, West Virginia": "تصنيف:التعليم في مقاطعة غرينبريه (فرجينيا الغربية)",
    "Category:Education in Hampshire County, West Virginia": "تصنيف:التعليم في مقاطعة هامبشاير (فرجينيا الغربية)",
    "Category:Education in Harrisonburg, Virginia": "تصنيف:التعليم في هاريسونبورغ (فرجينيا)",
    "Category:Education in James City County, Virginia": "تصنيف:التعليم في مقاطعة جيمس سيتي (فرجينيا)",
    "Category:Education in Jefferson County, West Virginia": "تصنيف:التعليم في مقاطعة جيفيرسون (فرجينيا الغربية)",
    "Category:Education in Lexington, Virginia": "تصنيف:التعليم في كسينغتون (فرجينيا)",
    "Category:Education in Loudoun County, Virginia": "تصنيف:التعليم في مقاطعة لودون (فرجينيا)",
    "Category:Education in Martinsburg, West Virginia": "تصنيف:التعليم في مرتينسبورغ (فرجينيا الغربية)",
    "Category:Education in Monongalia County, West Virginia": "تصنيف:التعليم في مقاطعة مونونغاليا (فرجينيا الغربية)",
    "Category:Education in Montgomery County, Virginia": "تصنيف:التعليم في مقاطعة مونغومري (فرجينيا)",
    "Category:Education in Ohio County, West Virginia": "تصنيف:التعليم في مقاطعة أوهايو (فرجينيا الغربية)",
    "Category:Education in Portsmouth, Virginia": "تصنيف:التعليم في بورتسموث (فرجينيا)",
    "Category:Education in Prince William County, Virginia": "تصنيف:التعليم في مقاطعة برينس ويليام (فرجينيا)",
    "Category:Education in Radford, Virginia": "تصنيف:التعليم في رادفورد (فرجينيا)",
    "Category:Education in Raleigh County, West Virginia": "تصنيف:التعليم في مقاطعة رالي (فرجينيا الغربية)",
    "Category:Education in Romney, West Virginia": "تصنيف:التعليم في رومني (فرجينيا الغربية)",
    "Category:Education in Virginia": "تصنيف:التعليم في فرجينيا",
    "Category:Educational buildings in West Virginia": "تصنيف:مبان تعليمية في فرجينيا الغربية",
    "Category:Educational buildings on the National Register of Historic Places in West Virginia": "تصنيف:مبان تعليمية في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "Category:Educational organizations based in West Virginia": "تصنيف:منظمات تعليمية مقرها في فرجينيا الغربية",
    "Category:Educators from Bluefield, West Virginia": "تصنيف:معلمون من بلوفيلد (فرجينيا الغربية)",
    "Category:Educators from Charleston, West Virginia": "تصنيف:معلمون من تشارلستون (فرجينيا الغربية)",
    "Category:Educators from Huntington, West Virginia": "تصنيف:معلمون من هنغتينغتون (فرجينيا الغربية)",
    "Category:Educators from Martinsburg, West Virginia": "تصنيف:معلمون من مرتينسبورغ (فرجينيا الغربية)",
    "Category:Educators from Romney, West Virginia": "تصنيف:معلمون من رومني (فرجينيا الغربية)",
    "Category:Educators from Wheeling, West Virginia": "تصنيف:معلمون من ويلينغ (فرجينيا الغربية)",
    "Category:Entertainers from Fredericksburg, Virginia": "تصنيف:فنانون ترفيهيون من فريدريكسبيورغ (فرجينيا)",
    "Category:Episcopalians from West Virginia": "تصنيف:أسقفيون من فرجينيا الغربية",
    "Category:Essays by Virginia Woolf": "تصنيف:مقالات بواسطة فرجينيا وولف",
    "Category:Essex County, Virginia": "تصنيف:مقاطعة إيسيكس (فرجينيا)",
    "Category:Fairfax, Virginia": "تصنيف:فيرفاكس (فرجينيا)",
    "Category:Fairfax County, Virginia": "تصنيف:مقاطعة فيرفاكس (فرجينيا)",
    "Category:Fayetteville, West Virginia": "تصنيف:فايتفيل (فرجينيا الغربية)",
    "Category:Film producers from West Virginia": "تصنيف:منتجو أفلام من فرجينيا الغربية",
    "Category:Films based on works by Virginia Woolf": "تصنيف:أفلام مبنية على أعمال فرجينيا وولف",
    "Category:Films set in Virginia": "تصنيف:أفلام تقع أحداثها في فرجينيا",
    "Category:Fires in West Virginia": "تصنيف:حرائق في فرجينيا الغربية",
    "Category:Floods in West Virginia": "تصنيف:فيضانات في فرجينيا الغربية",
    "Category:Floyd County, Virginia": "تصنيف:مقاطعة فلويد (فرجينيا)",
    "Category:Fluvanna County, Virginia": "تصنيف:مقاطعة فلوفانان (فرجينيا)",
    "Category:Former buildings and structures in West Virginia": "تصنيف:مبان ومنشآت سابقة في فرجينيا الغربية",
    "Category:Franklin, Virginia": "تصنيف:فرانكلين (فرجينيا)",
    "Category:Franklin County, Virginia": "تصنيف:مقاطعة فرانكلين (فرجينيا)",
    "Category:Frederick County, Virginia": "تصنيف:مقاطعة فريدريك (فرجينيا)",
    "Category:Front Royal, Virginia": "تصنيف:فرونت رويال (فرجينيا)",
    "Category:Geography of Albemarle County, Virginia": "تصنيف:جغرافيا مقاطعة ألبمارل (فرجينيا)",
    "Category:Geography of Alexandria, Virginia": "تصنيف:جغرافيا الإسكندرية (فرجينيا)",
    "Category:Geography of Arlington County, Virginia": "تصنيف:جغرافيا مقاطعة أرلنغتون (فرجينيا)",
    "Category:Geography of Berkeley County, West Virginia": "تصنيف:جغرافيا مقاطعة بيركلي (فرجينيا الغربية)",
    "Category:Geography of Boone County, West Virginia": "تصنيف:جغرافيا مقاطعة بوون (فرجينيا الغربية)",
    "Category:Geography of Grant County, West Virginia": "تصنيف:جغرافيا مقاطعة غرانت (فرجينيا الغربية)",
    "Category:Geography of Jackson County, West Virginia": "تصنيف:جغرافيا مقاطعة جاكسون (فرجينيا الغربية)",
    "Category:Geography of James City County, Virginia": "تصنيف:جغرافيا مقاطعة جيمس سيتي (فرجينيا)",
    "Category:Geography of King George County, Virginia": "تصنيف:جغرافيا مقاطعة كينغ جورج (فرجينيا)",
    "Category:Geography of Pleasants County, West Virginia": "تصنيف:جغرافيا مقاطعة بلاسانتس (فرجينيا الغربية)",
    "Category:Geography of Preston County, West Virginia": "تصنيف:جغرافيا مقاطعة بريستون (فرجينيا الغربية)",
    "Category:Geography of Prince Edward County, Virginia": "تصنيف:جغرافيا مقاطعة برينس إدورد (فرجينيا)",
    "Category:Geography of Ritchie County, West Virginia": "تصنيف:جغرافيا مقاطعة ريتشي (فرجينيا الغربية)",
    "Category:Geography of Taylor County, West Virginia": "تصنيف:جغرافيا مقاطعة تايلور (فرجينيا الغربية)",
    "Category:Geography of Tazewell County, Virginia": "تصنيف:جغرافيا مقاطعة تازويل (فرجينيا)",
    "Category:Geography of Tucker County, West Virginia": "تصنيف:جغرافيا مقاطعة تاكر (فرجينيا الغربية)",
    "Category:Geography of Williamsburg, Virginia": "تصنيف:جغرافيا ويليامزبرغ (فرجينيا)",
    "Category:Geography of Winchester, Virginia": "تصنيف:جغرافيا وينشستر (فرجينيا)",
    "Category:Giles County, Virginia": "تصنيف:مقاطعة غيلز (فرجينيا)",
    "Category:Gilmer County, West Virginia": "تصنيف:مقاطعة غيلمر (فرجينيا الغربية)",
    "Category:Gloucester County, Virginia": "تصنيف:مقاطعة غلوستر (فرجينيا)",
    "Category:Goochland County, Virginia": "تصنيف:مقاطعة غووتشلاند (فرجينيا)",
    "Category:Government buildings in West Virginia": "تصنيف:مبان حكومية في فرجينيا الغربية",
    "Category:Grayson County, Virginia": "تصنيف:مقاطعة غرايسون (فرجينيا)",
    "Category:Greenbrier County, West Virginia": "تصنيف:مقاطعة غرينبريه (فرجينيا الغربية)",
    "Category:Greene County, Virginia": "تصنيف:مقاطعة غرين (فرجينيا)",
    "Category:Greensville County, Virginia": "تصنيف:مقاطعة غرينزفيل (فرجينيا)",
    "Category:Gymnastics in West Virginia": "تصنيف:الجمباز في فرجينيا الغربية",
    "Category:Halifax County, Virginia": "تصنيف:مقاطعة هاليفاكس (فرجينيا)",
    "Category:Hampshire County, West Virginia": "تصنيف:مقاطعة هامبشاير (فرجينيا الغربية)",
    "Category:Hampton, Virginia": "تصنيف:هامبتون (فرجينيا)",
    "Category:Hancock County, West Virginia": "تصنيف:مقاطعة هانكوك (فرجينيا الغربية)",
    "Category:Hanover County, Virginia": "تصنيف:مقاطعة هانوفر (فرجينيا)",
    "Category:Harpers Ferry, West Virginia": "تصنيف:هاربرز فيري (فرجينيا الغربية)",
    "Category:Henrico County, Virginia": "تصنيف:مقاطعة هنريكو (فرجينيا)",
    "Category:Henry County, Virginia": "تصنيف:مقاطعة هنري (فرجينيا)",
    "Category:Herndon, Virginia": "تصنيف:هيرندون (فرجينيا)",
    "Category:Highland County, Virginia": "تصنيف:مقاطعة هايلاند (فرجينيا)",
    "Category:History of Alexandria, Virginia": "تصنيف:تاريخ الإسكندرية (فرجينيا)",
    "Category:History of Virginia": "تصنيف:تاريخ فرجينيا",
    "Category:History of women in West Virginia": "تصنيف:تاريخ المرأة في فرجينيا الغربية",
    "Category:Hotel buildings on the National Register of Historic Places in West Virginia": "تصنيف:مبان فنادق في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "Category:International schools in West Virginia": "تصنيف:مدارس دولية في فرجينيا الغربية",
    "Category:Islands of Kanawha County, West Virginia": "تصنيف:جزر مقاطعة كاناوا (فرجينيا الغربية)",
    "Category:Italian-American culture in West Virginia": "تصنيف:ثقافة أمريكية إيطالية في فرجينيا الغربية",
    "Category:Jackson County, West Virginia": "تصنيف:مقاطعة جاكسون (فرجينيا الغربية)",
    "Category:James City County, Virginia": "تصنيف:مقاطعة جيمس سيتي (فرجينيا)",
    "Category:Journalists from Alexandria, Virginia": "تصنيف:صحفيون من الإسكندرية (فرجينيا)",
    "Category:King and Queen County, Virginia": "تصنيف:مقاطعة كينغ أند كوين (فرجينيا)",
    "Category:King George County, Virginia": "تصنيف:مقاطعة كينغ جورج (فرجينيا)",
    "Category:King William County, Virginia": "تصنيف:مقاطعة كينغ ويليام (فرجينيا)",
    "Category:Lancaster County, Virginia": "تصنيف:مقاطعة لانكستر (فرجينيا)",
    "Category:Landforms of Greenbrier County, West Virginia": "تصنيف:تضاريس مقاطعة غرينبريه (فرجينيا الغربية)",
    "Category:Landforms of King George County, Virginia": "تصنيف:تضاريس مقاطعة كينغ جورج (فرجينيا)",
    "Category:Landforms of Randolph County, West Virginia": "تصنيف:تضاريس مقاطعة راندولف (فرجينيا الغربية)",
    "Category:Lawyers from Alexandria, Virginia": "تصنيف:محامون من الإسكندرية (فرجينيا)",
    "Category:Lawyers from Beckley, West Virginia": "تصنيف:محامون من بيكلي (فرجينيا الغربية)",
    "Category:Lawyers from Bluefield, West Virginia": "تصنيف:محامون من بلوفيلد (فرجينيا الغربية)",
    "Category:Lawyers from Charleston, West Virginia": "تصنيف:محامون من تشارلستون (فرجينيا الغربية)",
    "Category:Lawyers from Clarksburg, West Virginia": "تصنيف:محامون من كلاركسبورغ (فرجينيا الغربية)",
    "Category:Lawyers from Fairmont, West Virginia": "تصنيف:محامون من فيرمونت (فرجينيا الغربية)",
    "Category:Lawyers from Martinsburg, West Virginia": "تصنيف:محامون من مرتينسبورغ (فرجينيا الغربية)",
    "Category:Lawyers from Morgantown, West Virginia": "تصنيف:محامون من مورغانتاون (فرجينيا الغربية)",
    "Category:Lawyers from Parkersburg, West Virginia": "تصنيف:محامون من باركرسبورغ (فرجينيا الغربية)",
    "Category:Lawyers from Roanoke, Virginia": "تصنيف:محامون من روانوك (فرجينيا)",
    "Category:Lawyers from Romney, West Virginia": "تصنيف:محامون من رومني (فرجينيا الغربية)",
    "Category:Lawyers from Wheeling, West Virginia": "تصنيف:محامون من ويلينغ (فرجينيا الغربية)",
    "Category:Lee County, Virginia": "تصنيف:مقاطعة لي (فرجينيا)",
    "Category:Leesburg, Virginia": "تصنيف:ليسبورغ (فرجينيا)",
    "Category:Libraries in West Virginia": "تصنيف:مكتبات في فرجينيا الغربية",
    "Category:Libraries on the National Register of Historic Places in West Virginia": "تصنيف:مكتبات في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "Category:Lincoln County, West Virginia": "تصنيف:مقاطعة لينكون (فرجينيا الغربية)",
    "Category:Lists of mayors of places in West Virginia": "تصنيف:قوائم رؤساء بلديات في فرجينيا الغربية",
    "Category:Lists of people from West Virginia": "تصنيف:قوائم أشخاص من فرجينيا الغربية",
    "Category:Lists of West Virginia politicians": "تصنيف:قوائم سياسيو فرجينيا الغربية",
    "Category:Loudoun County, Virginia": "تصنيف:مقاطعة لودون (فرجينيا)",
    "Category:Louisa, Virginia": "تصنيف:لوييسا (فرجينيا)",
    "Category:Louisa County, Virginia": "تصنيف:مقاطعة لويزا (فرجينيا)",
    "Category:Lunenburg County, Virginia": "تصنيف:مقاطعة لونينبرغ (فرجينيا)",
    "Category:Madison County, Virginia": "تصنيف:مقاطعة ماديسون (فرجينيا)",
    "Category:Male actors from Charleston, West Virginia": "تصنيف:ممثلون ذكور من تشارلستون (فرجينيا الغربية)",
    "Category:Male actors from Fairfax, Virginia": "تصنيف:ممثلون ذكور من فيرفاكس (فرجينيا)",
    "Category:Marshall County, West Virginia": "تصنيف:مقاطعة مارشال (فرجينيا الغربية)",
    "Category:Martinsville, Virginia": "تصنيف:مارتينسفيل (فرجينيا)",
    "Category:Mason County, West Virginia": "تصنيف:مقاطعة ماسون (فرجينيا الغربية)",
    "Category:Mathews County, Virginia": "تصنيف:مقاطعة ماثيوز (فرجينيا)",
    "Category:Mayors of Alexandria, Virginia": "تصنيف:عمدات الإسكندرية (فرجينيا)",
    "Category:Mayors of Charleston, West Virginia": "تصنيف:عمدات تشارلستون (فرجينيا الغربية)",
    "Category:Mayors of Huntington, West Virginia": "تصنيف:عمدات هنغتينغتون (فرجينيا الغربية)",
    "Category:Mayors of Lynchburg, Virginia": "تصنيف:عمدات لينشبرغ (فرجينيا)",
    "Category:Mayors of Morgantown, West Virginia": "تصنيف:عمدات مورغانتاون (فرجينيا الغربية)",
    "Category:Mayors of places in West Virginia by century": "تصنيف:رؤساء بلديات في فرجينيا الغربية حسب القرن",
    "Category:Mayors of Roanoke, Virginia": "تصنيف:عمدات روانوك (فرجينيا)",
    "Category:Mayors of Staunton, Virginia": "تصنيف:عمدات ستونتون (فرجينيا)",
    "Category:McDowell County, West Virginia": "تصنيف:مقاطعة مكداويل (فرجينيا الغربية)",
    "Category:Mecklenburg County, Virginia": "تصنيف:مقاطعة ميكلينبرغ (فرجينيا)",
    "Category:Medical and health organizations based in West Virginia": "تصنيف:منظمات طبية وصحية مقرها في فرجينيا الغربية",
    "Category:Medical schools in West Virginia": "تصنيف:مدارس طبية في فرجينيا الغربية",
    "Category:Members of the West Virginia Board of Education": "تصنيف:أعضاء مجلس التعليم في ولاية فرجينيا الغربية",
    "Category:Methodists from West Virginia": "تصنيف:ميثوديون من فرجينيا الغربية",
    "Category:Middlesex County, Virginia": "تصنيف:مقاطعة ميديلسكس (فرجينيا)",
    "Category:Military personnel from Alexandria, Virginia": "تصنيف:أفراد عسكريون من الإسكندرية (فرجينيا)",
    "Category:Military personnel from Beckley, West Virginia": "تصنيف:أفراد عسكريون من بيكلي (فرجينيا الغربية)",
    "Category:Military personnel from Bluefield, West Virginia": "تصنيف:أفراد عسكريون من بلوفيلد (فرجينيا الغربية)",
    "Category:Military personnel from Charleston, West Virginia": "تصنيف:أفراد عسكريون من تشارلستون (فرجينيا الغربية)",
    "Category:Military personnel from Clarksburg, West Virginia": "تصنيف:أفراد عسكريون من كلاركسبورغ (فرجينيا الغربية)",
    "Category:Military personnel from Fairfax, Virginia": "تصنيف:أفراد عسكريون من فيرفاكس (فرجينيا)",
    "Category:Military personnel from Fredericksburg, Virginia": "تصنيف:أفراد عسكريون من فريدريكسبيورغ (فرجينيا)",
    "Category:Military personnel from Lynchburg, Virginia": "تصنيف:أفراد عسكريون من لينشبرغ (فرجينيا)",
    "Category:Military personnel from Martinsburg, West Virginia": "تصنيف:أفراد عسكريون من مرتينسبورغ (فرجينيا الغربية)",
    "Category:Military personnel from Morgantown, West Virginia": "تصنيف:أفراد عسكريون من مورغانتاون (فرجينيا الغربية)",
    "Category:Military personnel from Parkersburg, West Virginia": "تصنيف:أفراد عسكريون من باركرسبورغ (فرجينيا الغربية)",
    "Category:Military personnel from Portsmouth, Virginia": "تصنيف:أفراد عسكريون من بورتسموث (فرجينيا)",
    "Category:Military personnel from Princeton, West Virginia": "تصنيف:أفراد عسكريون من برينستون (فرجينيا الغربية)",
    "Category:Military personnel from Romney, West Virginia": "تصنيف:أفراد عسكريون من رومني (فرجينيا الغربية)",
    "Category:Military personnel from West Virginia by populated place": "تصنيف:أفراد عسكريون من فرجينيا الغربية حسب المكان المأهول",
    "Category:Military personnel from Wheeling, West Virginia": "تصنيف:أفراد عسكريون من ويلينغ (فرجينيا الغربية)",
    "Category:Mineral County, West Virginia": "تصنيف:مقاطعة مينيرال (فرجينيا الغربية)",
    "Category:Mingo County, West Virginia": "تصنيف:مقاطعة مينغو (فرجينيا الغربية)",
    "Category:Mixed martial arts in West Virginia": "تصنيف:فنون القتال المختلطة في فرجينيا الغربية",
    "Category:Monongalia County, West Virginia": "تصنيف:مقاطعة مونونغاليا (فرجينيا الغربية)",
    "Category:Montgomery County, Virginia": "تصنيف:مقاطعة مونغومري (فرجينيا)",
    "Category:Mountain ranges of West Virginia": "تصنيف:سلاسل جبلية في فرجينيا الغربية",
    "Category:Museums in Albemarle County, Virginia": "تصنيف:متاحف في مقاطعة ألبمارل (فرجينيا)",
    "Category:Museums in Alexandria, Virginia": "تصنيف:متاحف في الإسكندرية (فرجينيا)",
    "Category:Museums in Fairfax County, Virginia": "تصنيف:متاحف في مقاطعة فيرفاكس (فرجينيا)",
    "Category:Museums in Greenbrier County, West Virginia": "تصنيف:متاحف في مقاطعة غرينبريه (فرجينيا الغربية)",
    "Category:Museums in Hampshire County, West Virginia": "تصنيف:متاحف في مقاطعة هامبشاير (فرجينيا الغربية)",
    "Category:Museums in West Virginia": "تصنيف:متاحف في فرجينيا الغربية",
    "Category:Museums in West Virginia by county": "تصنيف:متاحف في فرجينيا الغربية حسب المقاطعة",
    "Category:Museums in Williamsburg, Virginia": "تصنيف:متاحف في ويليامزبرغ (فرجينيا)",
    "Category:Museums on the National Register of Historic Places in West Virginia": "تصنيف:متاحف في السجل الوطني للأماكن التاريخية في فرجينيا الغربية",
    "Category:Musicians from Alexandria, Virginia": "تصنيف:موسيقيون من الإسكندرية (فرجينيا)",
    "Category:Musicians from Beckley, West Virginia": "تصنيف:موسيقيون من بيكلي (فرجينيا الغربية)",
    "Category:Musicians from Bluefield, West Virginia": "تصنيف:موسيقيون من بلوفيلد (فرجينيا الغربية)",
    "Category:Musicians from Charleston, West Virginia": "تصنيف:موسيقيون من تشارلستون (فرجينيا الغربية)",
    "Category:Musicians from Martinsburg, West Virginia": "تصنيف:موسيقيون من مرتينسبورغ (فرجينيا الغربية)",
    "Category:Musicians from Portsmouth, Virginia": "تصنيف:موسيقيون من بورتسموث (فرجينيا)",
    "Category:Musicians from Princeton, West Virginia": "تصنيف:موسيقيون من برينستون (فرجينيا الغربية)",
    "Category:Musicians from West Virginia by genre": "تصنيف:موسيقيون من فرجينيا الغربية حسب النوع الفني",
    "Category:Musicians from Wheeling, West Virginia": "تصنيف:موسيقيون من ويلينغ (فرجينيا الغربية)",
    "Category:National Natural Landmarks in West Virginia": "تصنيف:معالم طبيعية وطنية في فرجينيا الغربية",
    "Category:National Register of Historic Places in Alexandria, Virginia": "تصنيف:السجل الوطني للأماكن التاريخية في الإسكندرية (فرجينيا)",
    "Category:National Register of Historic Places in Fredericksburg, Virginia": "تصنيف:السجل الوطني للأماكن التاريخية في فريدريكسبيورغ (فرجينيا)",
    "Category:National Register of Historic Places in Hampshire County, West Virginia": "تصنيف:السجل الوطني للأماكن التاريخية في مقاطعة هامبشاير (فرجينيا الغربية)",
    "Category:National Register of Historic Places in Lexington, Virginia": "تصنيف:السجل الوطني للأماكن التاريخية في كسينغتون (فرجينيا)",
    "Category:National Register of Historic Places in Wheeling, West Virginia": "تصنيف:السجل الوطني للأماكن التاريخية في ويلينغ (فرجينيا الغربية)",
    "Category:National Register of Historic Places in Williamsburg, Virginia": "تصنيف:السجل الوطني للأماكن التاريخية في ويليامزبرغ (فرجينيا)",
    "Category:National Register of Historic Places in Winchester, Virginia": "تصنيف:السجل الوطني للأماكن التاريخية في وينشستر (فرجينيا)",
    "Category:Nelson County, Virginia": "تصنيف:مقاطعة نيلسون (فرجينيا)",
    "Category:New Kent County, Virginia": "تصنيف:مقاطعة كينت الجديدة (فرجينيا)",
    "Category:Non-profit organizations based in Alexandria, Virginia": "تصنيف:منظمات غير ربحية مقرها في الإسكندرية (فرجينيا)",
    "Category:Non-profit organizations based in Fairfax, Virginia": "تصنيف:منظمات غير ربحية مقرها في فيرفاكس (فرجينيا)",
    "Category:Non-profit organizations based in Herndon, Virginia": "تصنيف:منظمات غير ربحية مقرها في هيرندون (فرجينيا)",
    "Category:Non-profit organizations based in Lynchburg, Virginia": "تصنيف:منظمات غير ربحية مقرها في لينشبرغ (فرجينيا)",
    "Category:Non-profit organizations based in West Virginia": "تصنيف:منظمات غير ربحية مقرها في فرجينيا الغربية",
    "Category:Northampton County, Virginia": "تصنيف:مقاطعة نورثهامبتون (فرجينيا)",
    "Category:Northumberland County, Virginia": "تصنيف:مقاطعة نورثومبرلاند (فرجينيا)",
    "Category:Norton, Virginia": "تصنيف:نورتون (فرجينيا)",
    "Category:Nottoway County, Virginia": "تصنيف:مقاطعة نوتوواي (فرجينيا)",
    "Category:Orange County, Virginia": "تصنيف:مقاطعة أورانج (فرجينيا)",
    "Category:Organizations based in Alexandria, Virginia": "تصنيف:منظمات مقرها في الإسكندرية (فرجينيا)",
    "Category:Organizations based in West Virginia": "تصنيف:منظمات مقرها في فرجينيا الغربية",
    "Category:Page County, Virginia": "تصنيف:مقاطعة بيج (فرجينيا)",
    "Category:Parks in Williamsburg, Virginia": "تصنيف:متنزهات في ويليامزبرغ (فرجينيا)",
    "Category:Patrick County, Virginia": "تصنيف:مقاطعة باتريك (فرجينيا)",
    "Category:People by university or college in Virginia": "تصنيف:أشخاص حسب الجامعة أو الكلية في فرجينيا",
    "Category:People from Accomack County, Virginia": "تصنيف:أشخاص من مقاطعة أكوماك (فرجينيا)",
    "Category:People from Albemarle County, Virginia": "تصنيف:أشخاص من مقاطعة ألبمارل (فرجينيا)",
    "Category:People from Alderson, West Virginia": "تصنيف:أشخاص من ألدرسن (فرجينيا الغربية)",
    "Category:People from Alleghany County, Virginia": "تصنيف:أشخاص من مقاطعة أليغاني (فرجينيا)",
    "Category:People from Amelia County, Virginia": "تصنيف:أشخاص من مقاطعة أميليا (فرجينيا)",
    "Category:People from Amherst County, Virginia": "تصنيف:أشخاص من مقاطعة أمهيرست (فرجينيا)",
    "Category:People from Appomattox County, Virginia": "تصنيف:أشخاص من مقاطعة أبوماتوكس (فرجينيا)",
    "Category:People from Arlington County, Virginia": "تصنيف:أشخاص من مقاطعة أرلنغتون (فرجينيا)",
    "Category:People from Augusta County, Virginia": "تصنيف:أشخاص من مقاطعة أوغوستا (فرجينيا)",
    "Category:People from Bath County, Virginia": "تصنيف:أشخاص من مقاطعة باث (فرجينيا)",
    "Category:People from Bedford County, Virginia": "تصنيف:أشخاص من مقاطعة بيدفورد (فرجينيا)",
    "Category:People from Berkeley County, West Virginia": "تصنيف:أشخاص من مقاطعة بيركلي (فرجينيا الغربية)",
    "Category:People from Bethany, West Virginia": "تصنيف:أشخاص من بيثاني (فرجينيا الغربية)",
    "Category:People from Beverly, West Virginia": "تصنيف:أشخاص من بيفرلي (فرجينيا الغربية)",
    "Category:People from Boone County, West Virginia": "تصنيف:أشخاص من مقاطعة بوون (فرجينيا الغربية)",
    "Category:People from Botetourt County, Virginia": "تصنيف:أشخاص من مقاطعة بوتيتورت (فرجينيا)",
    "Category:People from Bramwell, West Virginia": "تصنيف:أشخاص من برامويل (فرجينيا الغربية)",
    "Category:People from Braxton County, West Virginia": "تصنيف:أشخاص من مقاطعة براكستون (فرجينيا الغربية)",
    "Category:People from Bristol, Virginia": "تصنيف:أشخاص من بريستول (فرجينيا)",
    "Category:People from Brooke County, West Virginia": "تصنيف:أشخاص من مقاطعة بروك (فرجينيا الغربية)",
    "Category:People from Brunswick County, Virginia": "تصنيف:أشخاص من مقاطعة برونزويك (فرجينيا)",
    "Category:People from Buchanan, Virginia": "تصنيف:أشخاص من بوتشانان (فرجينيا)",
    "Category:People from Buchanan County, Virginia": "تصنيف:أشخاص من مقاطعة بوكانان (فرجينيا)",
    "Category:People from Buffalo, West Virginia": "تصنيف:أشخاص من بوفالو (فرجينيا الغربية)",
    "Category:People from Burkeville, Virginia": "تصنيف:أشخاص من بوركفيل (فرجينيا)",
    "Category:People from Burnsville, West Virginia": "تصنيف:أشخاص من بورنسفيل (فرجينيا الغربية)",
    "Category:People from Chapmanville, West Virginia": "تصنيف:أشخاص من تشامبانفيل (فرجينيا الغربية)",
    "Category:People from Charlotte County, Virginia": "تصنيف:أشخاص من مقاطعة شارلوت (فرجينيا)",
    "Category:People from Chatham, Virginia": "تصنيف:أشخاص من تشاتهام (فرجينيا)",
    "Category:People from Chesterfield County, Virginia": "تصنيف:أشخاص من مقاطعة تشيسترفيلد (فرجينيا)",
    "Category:People from Clay County, West Virginia": "تصنيف:أشخاص من مقاطعة كلاي (فرجينيا الغربية)",
    "Category:People from Clendenin, West Virginia": "تصنيف:أشخاص من كليندنين (فرجينيا الغربية)",
    "Category:People from Clifton, Virginia": "تصنيف:أشخاص من كليفتون (فرجينيا)",
    "Category:People from Colonial Heights, Virginia": "تصنيف:أشخاص من كولونيل هايتس (فرجينيا)",
    "Category:People from Covington, Virginia": "تصنيف:أشخاص من كوفينغتون (فرجينيا)",
    "Category:People from Culpeper County, Virginia": "تصنيف:أشخاص من مقاطعة كلبيبر (فرجينيا)",
    "Category:People from Cumberland County, Virginia": "تصنيف:أشخاص من مقاطعة كومبرلاند (فرجينيا)",
    "Category:People from Danville, Virginia": "تصنيف:أشخاص من دانفيل (فرجينيا)",
    "Category:People from Dickenson County, Virginia": "تصنيف:أشخاص من مقاطعة ديكينسون (فرجينيا)",
    "Category:People from Dinwiddie County, Virginia": "تصنيف:أشخاص من مقاطعة دينويدي (فرجينيا)",
    "Category:People from Doddridge County, West Virginia": "تصنيف:أشخاص من مقاطعة دودريدج (فرجينيا الغربية)",
    "Category:People from Fairfax, Virginia": "تصنيف:أشخاص من فيرفاكس (فرجينيا)",
    "Category:People from Fairfax County, Virginia": "تصنيف:أشخاص من مقاطعة فيرفاكس (فرجينيا)",
    "Category:People from Fayetteville, West Virginia": "تصنيف:أشخاص من فايتفيل (فرجينيا الغربية)",
    "Category:People from Franklin, Virginia": "تصنيف:أشخاص من فرانكلين (فرجينيا)",
    "Category:People from Franklin County, Virginia": "تصنيف:أشخاص من مقاطعة فرانكلين (فرجينيا)",
    "Category:People from Front Royal, Virginia": "تصنيف:أشخاص من فرونت رويال (فرجينيا)",
    "Category:People from Galax, Virginia": "تصنيف:أشخاص من جالاكس (فرجينيا)",
    "Category:People from Giles County, Virginia": "تصنيف:أشخاص من مقاطعة غيلز (فرجينيا)",
    "Category:People from Gilmer County, West Virginia": "تصنيف:أشخاص من مقاطعة غيلمر (فرجينيا الغربية)",
    "Category:People from Goochland County, Virginia": "تصنيف:أشخاص من مقاطعة غووتشلاند (فرجينيا)",
    "Category:People from Greenbrier County, West Virginia": "تصنيف:أشخاص من مقاطعة غرينبريه (فرجينيا الغربية)",
    "Category:People from Greene County, Virginia": "تصنيف:أشخاص من مقاطعة غرين (فرجينيا)",
    "Category:People from Greensville County, Virginia": "تصنيف:أشخاص من مقاطعة غرينزفيل (فرجينيا)",
    "Category:People from Halifax County, Virginia": "تصنيف:أشخاص من مقاطعة هاليفاكس (فرجينيا)",
    "Category:People from Hampshire County, West Virginia": "تصنيف:أشخاص من مقاطعة هامبشاير (فرجينيا الغربية)",
    "Category:People from Hampton, Virginia": "تصنيف:أشخاص من هامبتون (فرجينيا)",
    "Category:People from Hancock County, West Virginia": "تصنيف:أشخاص من مقاطعة هانكوك (فرجينيا الغربية)",
    "Category:People from Hanover County, Virginia": "تصنيف:أشخاص من مقاطعة هانوفر (فرجينيا)",
    "Category:People from Hardy County, West Virginia": "تصنيف:أشخاص من مقاطعة هاردي (فرجينيا الغربية)",
    "Category:People from Henrico County, Virginia": "تصنيف:أشخاص من مقاطعة هنريكو (فرجينيا)",
    "Category:People from Herndon, Virginia": "تصنيف:أشخاص من هيرندون (فرجينيا)",
    "Category:People from Highland County, Virginia": "تصنيف:أشخاص من مقاطعة هايلاند (فرجينيا)",
    "Category:People from Hopewell, Virginia": "تصنيف:أشخاص من هوبويل (فرجينيا)",
    "Category:People from Jackson County, West Virginia": "تصنيف:أشخاص من مقاطعة جاكسون (فرجينيا الغربية)",
    "Category:People from Jamestown, Virginia": "تصنيف:أشخاص من جيمستاون (فرجينيا)",
    "Category:People from King and Queen County, Virginia": "تصنيف:أشخاص من مقاطعة كينغ أند كوين (فرجينيا)",
    "Category:People from King George County, Virginia": "تصنيف:أشخاص من مقاطعة كينغ جورج (فرجينيا)",
    "Category:People from King William County, Virginia": "تصنيف:أشخاص من مقاطعة كينغ ويليام (فرجينيا)",
    "Category:People from Leesburg, Virginia": "تصنيف:أشخاص من ليسبورغ (فرجينيا)",
    "Category:People from Lewis County, West Virginia": "تصنيف:أشخاص من مقاطعة لويس (فرجينيا الغربية)",
    "Category:People from Lexington, Virginia": "تصنيف:أشخاص من كسينغتون (فرجينيا)",
    "Category:People from Lincoln County, West Virginia": "تصنيف:أشخاص من مقاطعة لينكون (فرجينيا الغربية)",
    "Category:People from Louisa, Virginia": "تصنيف:أشخاص من لوييسا (فرجينيا)",
    "Category:People from Louisa County, Virginia": "تصنيف:أشخاص من مقاطعة لويزا (فرجينيا)",
    "Category:People from Lunenburg County, Virginia": "تصنيف:أشخاص من مقاطعة لونينبرغ (فرجينيا)",
    "Category:People from Madison County, Virginia": "تصنيف:أشخاص من مقاطعة ماديسون (فرجينيا)",
    "Category:People from Marshall County, West Virginia": "تصنيف:أشخاص من مقاطعة مارشال (فرجينيا الغربية)",
    "Category:People from Martinsville, Virginia": "تصنيف:أشخاص من مارتينسفيل (فرجينيا)",
    "Category:People from Mason County, West Virginia": "تصنيف:أشخاص من مقاطعة ماسون (فرجينيا الغربية)",
    "Category:People from McDowell County, West Virginia": "تصنيف:أشخاص من مقاطعة مكداويل (فرجينيا الغربية)",
    "Category:People from Mineral County, West Virginia": "تصنيف:أشخاص من مقاطعة مينيرال (فرجينيا الغربية)",
    "Category:People from Mingo County, West Virginia": "تصنيف:أشخاص من مقاطعة مينغو (فرجينيا الغربية)",
    "Category:People from Monongalia County, West Virginia": "تصنيف:أشخاص من مقاطعة مونونغاليا (فرجينيا الغربية)",
    "Category:People from Monroe County, West Virginia": "تصنيف:أشخاص من مقاطعة مونرو (فرجينيا الغربية)",
    "Category:People from Morgan County, West Virginia": "تصنيف:أشخاص من مقاطعة مورغان (فرجينيا الغربية)",
    "Category:People from Moundsville, West Virginia": "تصنيف:أشخاص من مووندسفيل (فرجينيا الغربية)",
    "Category:People from Nicholas County, West Virginia": "تصنيف:أشخاص من مقاطعة نيكولاس (فرجينيا الغربية)",
    "Category:People from Northampton County, Virginia": "تصنيف:أشخاص من مقاطعة نورثهامبتون (فرجينيا)",
    "Category:People from Norton, Virginia": "تصنيف:أشخاص من نورتون (فرجينيا)",
    "Category:People from Oak Hill, West Virginia": "تصنيف:أشخاص من أوك هيل (فرجينيا الغربية)",
    "Category:People from Ohio County, West Virginia": "تصنيف:أشخاص من مقاطعة أوهايو (فرجينيا الغربية)",
    "Category:People from Orange County, Virginia": "تصنيف:أشخاص من مقاطعة أورانج (فرجينيا)",
    "Category:People from Pittsylvania County, Virginia": "تصنيف:أشخاص من مقاطعة بيتيسيلفانيا (فرجينيا)",
    "Category:People from Pocahontas County, West Virginia": "تصنيف:أشخاص من مقاطعة بوكاهونتس (فرجينيا الغربية)",
    "Category:People from Poquoson, Virginia": "تصنيف:أشخاص من بوكيوسون (فرجينيا)",
    "Category:People from Portsmouth, Virginia": "تصنيف:أشخاص من بورتسموث (فرجينيا)",
    "Category:People from Powhatan County, Virginia": "تصنيف:أشخاص من مقاطعة باوهاتن (فرجينيا)",
    "Category:People from Preston County, West Virginia": "تصنيف:أشخاص من مقاطعة بريستون (فرجينيا الغربية)",
    "Category:People from Prince Edward County, Virginia": "تصنيف:أشخاص من مقاطعة برينس إدورد (فرجينيا)",
    "Category:People from Pulaski County, Virginia": "تصنيف:أشخاص من مقاطعة بولاسكي (فرجينيا)",
    "Category:People from Putnam County, West Virginia": "تصنيف:أشخاص من مقاطعة بوتنام (فرجينيا الغربية)",
    "Category:People from Raleigh County, West Virginia": "تصنيف:أشخاص من مقاطعة رالي (فرجينيا الغربية)",
    "Category:People from Randolph County, West Virginia": "تصنيف:أشخاص من مقاطعة راندولف (فرجينيا الغربية)",
    "Category:People from Reston, Virginia": "تصنيف:أشخاص من رستون (فرجينيا)",
    "Category:People from Richmond, Virginia": "تصنيف:أشخاص من ريتشموند (فرجينيا)",
    "Category:People from Ritchie County, West Virginia": "تصنيف:أشخاص من مقاطعة ريتشي (فرجينيا الغربية)",
    "Category:People from Rockbridge County, Virginia": "تصنيف:أشخاص من مقاطعة روكبريج (فرجينيا)",
    "Category:People from Rockingham County, Virginia": "تصنيف:أشخاص من مقاطعة روكنغهام (فرجينيا)",
    "Category:People from Romney, West Virginia": "تصنيف:أشخاص من رومني (فرجينيا الغربية)",
    "Category:People from Russell County, Virginia": "تصنيف:أشخاص من مقاطعة روسيل (فرجينيا)",
    "Category:People from Salem, Virginia": "تصنيف:أشخاص من سالم (فرجينيا)",
    "Category:People from Scott County, Virginia": "تصنيف:أشخاص من مقاطعة سكوت (فرجينيا)",
    "Category:People from Shepherdstown, West Virginia": "تصنيف:أشخاص من شبردزتاون (فرجينيا الغربية)",
    "Category:People from South Charleston, West Virginia": "تصنيف:أشخاص من ساوث تشارلستون (فرجينيا الغربية)",
    "Category:People from Southampton County, Virginia": "تصنيف:أشخاص من مقاطعة ساوثهامبتون (فرجينيا)",
    "Category:People from Spotsylvania County, Virginia": "تصنيف:أشخاص من مقاطعة سبوتسيلفانيا (فرجينيا)",
    "Category:People from Stafford County, Virginia": "تصنيف:أشخاص من مقاطعة ستافورد (فرجينيا)",
    "Category:People from Suffolk, Virginia": "تصنيف:أشخاص من سوفولك (فرجينيا)",
    "Category:People from Sussex County, Virginia": "تصنيف:أشخاص من مقاطعة سوسيكس (فرجينيا)",
    "Category:People from Taylor County, West Virginia": "تصنيف:أشخاص من مقاطعة تايلور (فرجينيا الغربية)",
    "Category:People from Tazewell County, Virginia": "تصنيف:أشخاص من مقاطعة تازويل (فرجينيا)",
    "Category:People from Tucker County, West Virginia": "تصنيف:أشخاص من مقاطعة تاكر (فرجينيا الغربية)",
    "Category:People from Tyler County, West Virginia": "تصنيف:أشخاص من مقاطعة تايلر (فرجينيا الغربية)",
    "Category:People from Upshur County, West Virginia": "تصنيف:أشخاص من مقاطعة أبشور (فرجينيا الغربية)",
    "Category:People from Virginia, Minnesota": "تصنيف:أشخاص من فرجينيا (منيسوتا)",
    "Category:People from Virginia City, Nevada": "تصنيف:أشخاص من فرجينيا سيتي",
    "Category:People from Waynesboro, Virginia": "تصنيف:أشخاص من واينيسبورو (فرجينيا)",
    "Category:People from Webster County, West Virginia": "تصنيف:أشخاص من مقاطعة ويبستر (فرجينيا الغربية)",
    "Category:People from West Virginia by century": "تصنيف:أشخاص من فرجينيا الغربية حسب القرن",
    "Category:People from West Virginia by occupation and populated place": "تصنيف:أشخاص من فرجينيا الغربية حسب المهنة والمكان المأهول",
    "Category:People from West Virginia in the War of 1812": "تصنيف:أشخاص من فرجينيا الغربية في حرب 1812",
    "Category:People from Westmoreland County, Virginia": "تصنيف:أشخاص من مقاطعة ويستمورلاند (فرجينيا)",
    "Category:People from Wetzel County, West Virginia": "تصنيف:أشخاص من مقاطعة ويتزل (فرجينيا الغربية)",
    "Category:People from Williamsburg, Virginia": "تصنيف:أشخاص من ويليامزبرغ (فرجينيا)",
    "Category:People from Winchester, Virginia": "تصنيف:أشخاص من وينشستر (فرجينيا)",
    "Category:People from Wirt County, West Virginia": "تصنيف:أشخاص من مقاطعة ويرت (فرجينيا الغربية)",
    "Category:People from Wyoming County, West Virginia": "تصنيف:أشخاص من مقاطعة وايومنغ (فرجينيا الغربية)",
    "Category:People from Wythe County, Virginia": "تصنيف:أشخاص من مقاطعة وايذ (فرجينيا)",
    "Category:Philosophers from West Virginia": "تصنيف:فلاسفة من فرجينيا الغربية",
    "Category:Physicians from Parkersburg, West Virginia": "تصنيف:أطباء من باركرسبورغ (فرجينيا الغربية)",
    "Category:Physicians from Wheeling, West Virginia": "تصنيف:أطباء من ويلينغ (فرجينيا الغربية)",
    "Category:Pittsylvania County, Virginia": "تصنيف:مقاطعة بيتيسيلفانيا (فرجينيا)",
    "Category:Players of American football from Alexandria, Virginia": "تصنيف:لاعبو كرة قدم أمريكية من الإسكندرية (فرجينيا)",
    "Category:Players of American football from Charleston, West Virginia": "تصنيف:لاعبو كرة قدم أمريكية من تشارلستون (فرجينيا الغربية)",
    "Category:Players of American football from Danville, Virginia": "تصنيف:لاعبو كرة قدم أمريكية من دانفيل (فرجينيا)",
    "Category:Players of American football from Fairfax, Virginia": "تصنيف:لاعبو كرة قدم أمريكية من فيرفاكس (فرجينيا)",
    "Category:Players of American football from Huntington, West Virginia": "تصنيف:لاعبو كرة قدم أمريكية من هنغتينغتون (فرجينيا الغربية)",
    "Category:Players of American football from Kanawha County, West Virginia": "تصنيف:لاعبو كرة قدم أمريكية من مقاطعة كاناوا (فرجينيا الغربية)",
    "Category:Players of American football from Lynchburg, Virginia": "تصنيف:لاعبو كرة قدم أمريكية من لينشبرغ (فرجينيا)",
    "Category:Players of American football from Portsmouth, Virginia": "تصنيف:لاعبو كرة قدم أمريكية من بورتسموث (فرجينيا)",
    "Category:Players of American football from Roanoke, Virginia": "تصنيف:لاعبو كرة قدم أمريكية من روانوك (فرجينيا)",
    "Category:Players of American football from Wheeling, West Virginia": "تصنيف:لاعبو كرة قدم أمريكية من ويلينغ (فرجينيا الغربية)",
    "Category:Players of Canadian football from West Virginia": "تصنيف:لاعبو كرة قدم كندية من فرجينيا الغربية",
    "Category:Pleasants County, West Virginia": "تصنيف:مقاطعة بلاسانتس (فرجينيا الغربية)",
    "Category:Pocahontas County, West Virginia": "تصنيف:مقاطعة بوكاهونتس (فرجينيا الغربية)",
    "Category:Politicians from Alexandria, Virginia": "تصنيف:سياسيون من الإسكندرية (فرجينيا)",
    "Category:Politicians from Beckley, West Virginia": "تصنيف:سياسيون من بيكلي (فرجينيا الغربية)",
    "Category:Politicians from Bluefield, West Virginia": "تصنيف:سياسيون من بلوفيلد (فرجينيا الغربية)",
    "Category:Politicians from Charleston, West Virginia": "تصنيف:سياسيون من تشارلستون (فرجينيا الغربية)",
    "Category:Politicians from Clarksburg, West Virginia": "تصنيف:سياسيون من كلاركسبورغ (فرجينيا الغربية)",
    "Category:Politicians from Danville, Virginia": "تصنيف:سياسيون من دانفيل (فرجينيا)",
    "Category:Politicians from Fairfax, Virginia": "تصنيف:سياسيون من فيرفاكس (فرجينيا)",
    "Category:Politicians from Fairmont, West Virginia": "تصنيف:سياسيون من فيرمونت (فرجينيا الغربية)",
    "Category:Politicians from Fredericksburg, Virginia": "تصنيف:سياسيون من فريدريكسبيورغ (فرجينيا)",
    "Category:Politicians from Martinsburg, West Virginia": "تصنيف:سياسيون من مرتينسبورغ (فرجينيا الغربية)",
    "Category:Politicians from Morgantown, West Virginia": "تصنيف:سياسيون من مورغانتاون (فرجينيا الغربية)",
    "Category:Politicians from Parkersburg, West Virginia": "تصنيف:سياسيون من باركرسبورغ (فرجينيا الغربية)",
    "Category:Politicians from Portsmouth, Virginia": "تصنيف:سياسيون من بورتسموث (فرجينيا)",
    "Category:Politicians from Princeton, West Virginia": "تصنيف:سياسيون من برينستون (فرجينيا الغربية)",
    "Category:Politicians from Roanoke, Virginia": "تصنيف:سياسيون من روانوك (فرجينيا)",
    "Category:Politicians from Romney, West Virginia": "تصنيف:سياسيون من رومني (فرجينيا الغربية)",
    "Category:Politicians from Suffolk, Virginia": "تصنيف:سياسيون من سوفولك (فرجينيا)",
    "Category:Politicians from Wheeling, West Virginia": "تصنيف:سياسيون من ويلينغ (فرجينيا الغربية)",
    "Category:Politicians from Winchester, Virginia": "تصنيف:سياسيون من وينشستر (فرجينيا)",
    "Category:Populated places in Berkeley County, West Virginia": "تصنيف:أماكن مأهولة في مقاطعة بيركلي (فرجينيا الغربية)",
    "Category:Populated places in Boone County, West Virginia": "تصنيف:أماكن مأهولة في مقاطعة بوون (فرجينيا الغربية)",
    "Category:Populated places in Grant County, West Virginia": "تصنيف:أماكن مأهولة في مقاطعة غرانت (فرجينيا الغربية)",
    "Category:Populated places in Jackson County, West Virginia": "تصنيف:أماكن مأهولة في مقاطعة جاكسون (فرجينيا الغربية)",
    "Category:Populated places in James City County, Virginia": "تصنيف:أماكن مأهولة في مقاطعة جيمس سيتي (فرجينيا)",
    "Category:Populated places in Mingo County, West Virginia": "تصنيف:أماكن مأهولة في مقاطعة مينغو (فرجينيا الغربية)",
    "Category:Populated places in Pleasants County, West Virginia": "تصنيف:أماكن مأهولة في مقاطعة بلاسانتس (فرجينيا الغربية)",
    "Category:Populated places in Preston County, West Virginia": "تصنيف:أماكن مأهولة في مقاطعة بريستون (فرجينيا الغربية)",
    "Category:Populated places in Prince Edward County, Virginia": "تصنيف:أماكن مأهولة في مقاطعة برينس إدورد (فرجينيا)",
    "Category:Populated places in Ritchie County, West Virginia": "تصنيف:أماكن مأهولة في مقاطعة ريتشي (فرجينيا الغربية)",
    "Category:Populated places in Taylor County, West Virginia": "تصنيف:أماكن مأهولة في مقاطعة تايلور (فرجينيا الغربية)",
    "Category:Populated places in Tucker County, West Virginia": "تصنيف:أماكن مأهولة في مقاطعة تاكر (فرجينيا الغربية)",
    "Category:Poquoson, Virginia": "تصنيف:بوكيوسون (فرجينيا)",
    "Category:Portsmouth, Virginia": "تصنيف:بورتسموث (فرجينيا)",
    "Category:Powhatan County, Virginia": "تصنيف:مقاطعة باوهاتن (فرجينيا)",
    "Category:Preston County, West Virginia": "تصنيف:مقاطعة بريستون (فرجينيا الغربية)",
    "Category:Prince Edward County, Virginia": "تصنيف:مقاطعة برينس إدورد (فرجينيا)",
    "Category:Prince George County, Virginia": "تصنيف:مقاطعة برينس جورج (فرجينيا)",
    "Category:Prince William County, Virginia": "تصنيف:مقاطعة برينس ويليام (فرجينيا)",
    "Category:Private universities and colleges in West Virginia": "تصنيف:جامعات وكليات خاصة في فرجينيا الغربية",
    "Category:Protected areas of Arlington County, Virginia": "تصنيف:مناطق محمية في مقاطعة أرلنغتون (فرجينيا)",
    "Category:Protected areas of Kanawha County, West Virginia": "تصنيف:مناطق محمية في مقاطعة كاناوا (فرجينيا الغربية)",
    "Category:Protected areas of Marshall County, West Virginia": "تصنيف:مناطق محمية في مقاطعة مارشال (فرجينيا الغربية)",
    "Category:Protected areas of Williamsburg, Virginia": "تصنيف:مناطق محمية في ويليامزبرغ (فرجينيا)",
    "Category:Protestantism in West Virginia": "تصنيف:البروتستانتية في فرجينيا الغربية",
    "Category:Public universities and colleges in West Virginia": "تصنيف:جامعات وكليات حكومية في فرجينيا الغربية",
    "Category:Pulaski County, Virginia": "تصنيف:مقاطعة بولاسكي (فرجينيا)",
    "Category:Quakerism in West Virginia": "تصنيف:الكويكرية في فرجينيا الغربية",
    "Category:Rabbis from West Virginia": "تصنيف:حاخامات من فرجينيا الغربية",
    "Category:Rabbis from Wheeling, West Virginia": "تصنيف:حاخامات من ويلينغ (فرجينيا الغربية)",
    "Category:Randolph County, West Virginia": "تصنيف:مقاطعة راندولف (فرجينيا الغربية)",
    "Category:Rappahannock County, Virginia": "تصنيف:مقاطعة راباهانوك (فرجينيا)",
    "Category:Regions of Virginia": "تصنيف:مناطق فرجينيا",
    "Category:Religious leaders from Charleston, West Virginia": "تصنيف:قادة دينيون من تشارلستون (فرجينيا الغربية)",
    "Category:Religious leaders from Huntington, West Virginia": "تصنيف:قادة دينيون من هنغتينغتون (فرجينيا الغربية)",
    "Category:Religious leaders from Martinsburg, West Virginia": "تصنيف:قادة دينيون من مرتينسبورغ (فرجينيا الغربية)",
    "Category:Religious leaders from Romney, West Virginia": "تصنيف:قادة دينيون من رومني (فرجينيا الغربية)",
    "Category:Religious leaders from Wheeling, West Virginia": "تصنيف:قادة دينيون من ويلينغ (فرجينيا الغربية)",
    "Category:Republican Party United States senators from West Virginia": "تصنيف:أعضاء مجلس الشيوخ الأمريكي من الحزب الجمهوري من فرجينيا الغربية",
    "Category:Research institutes in West Virginia": "تصنيف:معاهد أبحاث في فرجينيا الغربية",
    "Category:Reston, Virginia": "تصنيف:رستون (فرجينيا)",
    "Category:Richmond County, Virginia": "تصنيف:مقاطعة ريتشموند (فرجينيا)",
    "Category:Rivers of King George County, Virginia": "تصنيف:أنهار مقاطعة كينغ جورج (فرجينيا)",
    "Category:Roanoke County, Virginia": "تصنيف:مقاطعة رونوك (فرجينيا)",
    "Category:Rockbridge County, Virginia": "تصنيف:مقاطعة روكبريج (فرجينيا)",
    "Category:Rockingham County, Virginia": "تصنيف:مقاطعة روكنغهام (فرجينيا)",
    "Category:Russell County, Virginia": "تصنيف:مقاطعة روسيل (فرجينيا)",
    "Category:Salem, Virginia": "تصنيف:سالم (فرجينيا)",
    "Category:School board members in West Virginia": "تصنيف:أعضاء مجالس تعليمية في فرجينيا الغربية",
    "Category:Schools in Cabell County, West Virginia": "تصنيف:مدارس في مقاطعة كابيل (فرجينيا الغربية)",
    "Category:Schools in Hampshire County, West Virginia": "تصنيف:مدارس في مقاطعة هامبشاير (فرجينيا الغربية)",
    "Category:Schools in Romney, West Virginia": "تصنيف:مدارس في رومني (فرجينيا الغربية)",
    "Category:Schools in West Virginia by populated place": "تصنيف:مدارس في فرجينيا الغربية حسب المكان المأهول",
    "Category:Schoolteachers from West Virginia": "تصنيف:معلمو مدارس من فرجينيا الغربية",
    "Category:Scientists from Alexandria, Virginia": "تصنيف:علماء من الإسكندرية (فرجينيا)",
    "Category:Scientists from Bluefield, West Virginia": "تصنيف:علماء من بلوفيلد (فرجينيا الغربية)",
    "Category:Scientists from Charleston, West Virginia": "تصنيف:علماء من تشارلستون (فرجينيا الغربية)",
    "Category:Scientists from Huntington, West Virginia": "تصنيف:علماء من هنغتينغتون (فرجينيا الغربية)",
    "Category:Scientists from Morgantown, West Virginia": "تصنيف:علماء من مورغانتاون (فرجينيا الغربية)",
    "Category:Scientists from Parkersburg, West Virginia": "تصنيف:علماء من باركرسبورغ (فرجينيا الغربية)",
    "Category:Scientists from Wheeling, West Virginia": "تصنيف:علماء من ويلينغ (فرجينيا الغربية)",
    "Category:Scott County, Virginia": "تصنيف:مقاطعة سكوت (فرجينيا)",
    "Category:Screenwriters from West Virginia": "تصنيف:كتاب سيناريو من فرجينيا الغربية",
    "Category:Secretaries of state of West Virginia": "تصنيف:وزراء خارجية فرجينيا الغربية",
    "Category:Serial killers from West Virginia": "تصنيف:قتلة متسلسلون من فرجينيا الغربية",
    "Category:Shenandoah County, Virginia": "تصنيف:مقاطعة شيناندوا (فرجينيا)",
    "Category:Shepherdstown, West Virginia": "تصنيف:شبردزتاون (فرجينيا الغربية)",
    "Category:Ships built in Portsmouth, Virginia": "تصنيف:سفن بنيت في بورتسموث (فرجينيا)",
    "Category:Smyth County, Virginia": "تصنيف:مقاطعة سميث (فرجينيا)",
    "Category:Soccer players from Fairfax, Virginia": "تصنيف:لاعبو كرة قدم من فيرفاكس (فرجينيا)",
    "Category:Soccer players in West Virginia by club": "تصنيف:لاعبو كرة قدم في فرجينيا الغربية حسب النادي",
    "Category:Southampton County, Virginia": "تصنيف:مقاطعة ساوثهامبتون (فرجينيا)",
    "Category:Sports in Alexandria, Virginia": "تصنيف:ألعاب رياضية في الإسكندرية (فرجينيا)",
    "Category:Sports in Clarksburg, West Virginia": "تصنيف:ألعاب رياضية في كلاركسبورغ (فرجينيا الغربية)",
    "Category:Sports in Fairfax, Virginia": "تصنيف:ألعاب رياضية في فيرفاكس (فرجينيا)",
    "Category:Sports in Martinsburg, West Virginia": "تصنيف:ألعاب رياضية في مرتينسبورغ (فرجينيا الغربية)",
    "Category:Sports in Parkersburg, West Virginia": "تصنيف:ألعاب رياضية في باركرسبورغ (فرجينيا الغربية)",
    "Category:Sports in Roanoke, Virginia": "تصنيف:ألعاب رياضية في روانوك (فرجينيا)",
    "Category:Sports in West Virginia by sport": "تصنيف:الرياضة في فرجينيا الغربية حسب الرياضة",
    "Category:Sports in Williamsburg, Virginia": "تصنيف:ألعاب رياضية في ويليامزبرغ (فرجينيا)",
    "Category:Sportspeople from Alexandria, Virginia": "تصنيف:رياضيون من الإسكندرية (فرجينيا)",
    "Category:Sportspeople from Arlington County, Virginia": "تصنيف:رياضيون من مقاطعة أرلنغتون (فرجينيا)",
    "Category:Sportspeople from Danville, Virginia": "تصنيف:رياضيون من دانفيل (فرجينيا)",
    "Category:Sportspeople from Fairfax, Virginia": "تصنيف:رياضيون من فيرفاكس (فرجينيا)",
    "Category:Sportspeople from Fairfax County, Virginia": "تصنيف:رياضيون من مقاطعة فيرفاكس (فرجينيا)",
    "Category:Sportspeople from Fredericksburg, Virginia": "تصنيف:رياضيون من فريدريكسبيورغ (فرجينيا)",
    "Category:Sportspeople from Hancock County, West Virginia": "تصنيف:رياضيون من مقاطعة هانكوك (فرجينيا الغربية)",
    "Category:Sportspeople from Leesburg, Virginia": "تصنيف:رياضيون من ليسبورغ (فرجينيا)",
    "Category:Sportspeople from Manassas, Virginia": "تصنيف:رياضيون من ماناساس (فرجينيا)",
    "Category:Sportspeople from Martinsville, Virginia": "تصنيف:رياضيون من مارتينسفيل (فرجينيا)",
    "Category:Sportspeople from Morgan County, West Virginia": "تصنيف:رياضيون من مقاطعة مورغان (فرجينيا الغربية)",
    "Category:Sportspeople from Portsmouth, Virginia": "تصنيف:رياضيون من بورتسموث (فرجينيا)",
    "Category:Sportspeople from Reston, Virginia": "تصنيف:رياضيون من رستون (فرجينيا)",
    "Category:Sportspeople from Staunton, Virginia": "تصنيف:رياضيون من ستونتون (فرجينيا)",
    "Category:Sportspeople from Suffolk, Virginia": "تصنيف:رياضيون من سوفولك (فرجينيا)",
    "Category:Sportspeople from Virginia, Minnesota": "تصنيف:رياضيون من فرجينيا (منيسوتا)",
    "Category:Sportspeople from Williamsburg, Virginia": "تصنيف:رياضيون من ويليامزبرغ (فرجينيا)",
    "Category:Sportspeople from Wood County, West Virginia": "تصنيف:رياضيون من مقاطعة وود (فرجينيا الغربية)",
    "Category:Spotsylvania County, Virginia": "تصنيف:مقاطعة سبوتسيلفانيا (فرجينيا)",
    "Category:Stafford County, Virginia": "تصنيف:مقاطعة ستافورد (فرجينيا)",
    "Category:State agencies of West Virginia": "تصنيف:أجهزة الدولة في فرجينيا الغربية",
    "Category:State cabinet secretaries of West Virginia": "تصنيف:أعضاء مجلس وزراء فرجينيا الغربية",
    "Category:State treasurers of West Virginia": "تصنيف:أمناء خزينة ولاية فرجينيا الغربية",
    "Category:Suffolk, Virginia": "تصنيف:سوفولك (فرجينيا)",
    "Category:Surry County, Virginia": "تصنيف:مقاطعة سوري (فرجينيا)",
    "Category:Sussex County, Virginia": "تصنيف:مقاطعة سوسيكس (فرجينيا)",
    "Category:Swimming in West Virginia": "تصنيف:السباحة في فرجينيا الغربية",
    "Category:Swimming venues in West Virginia": "تصنيف:ملاعب السباحة في فرجينيا الغربية",
    "Category:Taylor County, West Virginia": "تصنيف:مقاطعة تايلور (فرجينيا الغربية)",
    "Category:Tazewell County, Virginia": "تصنيف:مقاطعة تازويل (فرجينيا)",
    "Category:Television shows filmed in West Virginia": "تصنيف:عروض تلفزيونية صورت في فرجينيا الغربية",
    "Category:Television shows set in West Virginia": "تصنيف:عروض تلفزيونية تقع أحداثها في فرجينيا الغربية",
    "Category:Tourist attractions in Albemarle County, Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة ألبمارل (فرجينيا)",
    "Category:Tourist attractions in Alexandria, Virginia": "تصنيف:مواقع جذب سياحي في الإسكندرية (فرجينيا)",
    "Category:Tourist attractions in Arlington County, Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة أرلنغتون (فرجينيا)",
    "Category:Tourist attractions in Danville, Virginia": "تصنيف:مواقع جذب سياحي في دانفيل (فرجينيا)",
    "Category:Tourist attractions in Fairfax County, Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة فيرفاكس (فرجينيا)",
    "Category:Tourist attractions in Floyd County, Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة فلويد (فرجينيا)",
    "Category:Tourist attractions in Grant County, West Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة غرانت (فرجينيا الغربية)",
    "Category:Tourist attractions in Hampshire County, West Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة هامبشاير (فرجينيا الغربية)",
    "Category:Tourist attractions in Harrisonburg, Virginia": "تصنيف:مواقع جذب سياحي في هاريسونبورغ (فرجينيا)",
    "Category:Tourist attractions in Kanawha County, West Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة كاناوا (فرجينيا الغربية)",
    "Category:Tourist attractions in Lexington, Virginia": "تصنيف:مواقع جذب سياحي في كسينغتون (فرجينيا)",
    "Category:Tourist attractions in Lynchburg, Virginia": "تصنيف:مواقع جذب سياحي في لينشبرغ (فرجينيا)",
    "Category:Tourist attractions in Marshall County, West Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة مارشال (فرجينيا الغربية)",
    "Category:Tourist attractions in Monongalia County, West Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة مونونغاليا (فرجينيا الغربية)",
    "Category:Tourist attractions in Montgomery County, Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة مونغومري (فرجينيا)",
    "Category:Tourist attractions in Pendleton County, West Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة بيندلتون (فرجينيا الغربية)",
    "Category:Tourist attractions in Tucker County, West Virginia": "تصنيف:مواقع جذب سياحي في مقاطعة تاكر (فرجينيا الغربية)",
    "Category:Tourist attractions in Winchester, Virginia": "تصنيف:مواقع جذب سياحي في وينشستر (فرجينيا)",
    "Category:Towns in Pleasants County, West Virginia": "تصنيف:بلدات في مقاطعة بلاسانتس (فرجينيا الغربية)",
    "Category:Towns in Prince Edward County, Virginia": "تصنيف:بلدات في مقاطعة برينس إدورد (فرجينيا)",
    "Category:Track and field in West Virginia": "تصنيف:سباقات المضمار والميدان في فرجينيا الغربية",
    "Category:Transportation buildings and structures in Mason County, West Virginia": "تصنيف:مبان ومنشآت نقل في مقاطعة ماسون (فرجينيا الغربية)",
    "Category:Transportation buildings and structures in West Virginia by county": "تصنيف:مبان ومنشآت نقل في فرجينيا الغربية حسب المقاطعة",
    "Category:Transportation in Alexandria, Virginia": "تصنيف:النقل في الإسكندرية (فرجينيا)",
    "Category:Transportation in Arlington County, Virginia": "تصنيف:النقل في مقاطعة أرلنغتون (فرجينيا)",
    "Category:Transportation in Fairfax County, Virginia": "تصنيف:النقل في مقاطعة فيرفاكس (فرجينيا)",
    "Category:Transportation in Loudoun County, Virginia": "تصنيف:النقل في مقاطعة لودون (فرجينيا)",
    "Category:Transportation in Northampton County, Virginia": "تصنيف:النقل في مقاطعة نورثهامبتون (فرجينيا)",
    "Category:Trustees of populated places in West Virginia": "تصنيف:أمناء أماكن مأهولة في فرجينيا الغربية",
    "Category:Tuberculosis deaths in West Virginia": "تصنيف:وفيات السل في فرجينيا الغربية",
    "Category:Tucker County, West Virginia": "تصنيف:مقاطعة تاكر (فرجينيا الغربية)",
    "Category:Unincorporated communities in Greenbrier County, West Virginia": "تصنيف:مجتمعات فردية في مقاطعة غرينبريه (فرجينيا الغربية)",
    "Category:Unincorporated communities in Jefferson County, West Virginia": "تصنيف:مجتمعات فردية في مقاطعة جيفيرسون (فرجينيا الغربية)",
    "Category:Unincorporated communities in Virginia": "تصنيف:مجتمعات فردية في فرجينيا",
    "Category:Unincorporated communities in West Virginia": "تصنيف:مجتمعات فردية في فرجينيا الغربية",
    "Category:Unincorporated communities in Wirt County, West Virginia": "تصنيف:مجتمعات فردية في مقاطعة ويرت (فرجينيا الغربية)",
    "Category:Universities and colleges in Lynchburg, Virginia": "تصنيف:جامعات وكليات في لينشبرغ (فرجينيا)",
    "Category:Universities and colleges in Virginia": "تصنيف:جامعات وكليات في فرجينيا",
    "Category:Universities and colleges in West Virginia by type": "تصنيف:جامعات وكليات في فرجينيا الغربية حسب الفئة",
    "Category:University of Virginia alumni": "تصنيف:خريجو جامعة فرجينيا",
    "Category:Upshur County, West Virginia": "تصنيف:مقاطعة أبشور (فرجينيا الغربية)",
    "Category:Virginia, Minnesota": "تصنيف:فرجينيا (منيسوتا)",
    "Category:Virginia Cavaliers football": "تصنيف:نادي فرجينيا كفاليرز",
    "Category:Virginia Cavaliers football coaches": "تصنيف:مدربو نادي فرجينيا كفاليرز",
    "Category:Virginia Cavaliers football players": "تصنيف:لاعبو نادي فرجينيا كفاليرز",
    "Category:Virginia City, Nevada": "تصنيف:فرجينيا سيتي",
    "Category:Virginia Squires": "تصنيف:فرجينيا سكوايرز",
    "Category:Virginia Squires coaches": "تصنيف:مدربو فرجينيا سكوايرز",
    "Category:Virginia Squires players": "تصنيف:لاعبو فرجينيا سكوايرز",
    "Category:Virginia Woolf": "تصنيف:فرجينيا وولف",
    "Category:Warren County, Virginia": "تصنيف:مقاطعة وارين (فرجينيا)",
    "Category:Washington County, Virginia": "تصنيف:مقاطعة واشنطن (فرجينيا)",
    "Category:Waynesboro, Virginia": "تصنيف:واينيسبورو (فرجينيا)",
    "Category:Webster County, West Virginia": "تصنيف:مقاطعة ويبستر (فرجينيا الغربية)",
    "Category:West Virginia Board of Education": "تصنيف:مجلس التعليم في ولاية فرجينيا الغربية",
    "Category:West Virginia Democrats": "تصنيف:ديمقراطيون من ولاية فرجينيا الغربية",
    "Category:West Virginia Greenbacks": "تصنيف:أعضاء حزب الدولار الأمريكي في فرجينيا الغربية",
    "Category:West Virginia independents": "تصنيف:مستقلون من ولاية فرجينيا الغربية",
    "Category:West Virginia politicians by century": "تصنيف:سياسيو فرجينيا الغربية حسب القرن",
    "Category:West Virginia politicians by party": "تصنيف:سياسيو فرجينيا الغربية حسب الحزب",
    "Category:West Virginia politics-related lists": "تصنيف:قوائم متعلقة بسياسة فرجينيا الغربية",
    "Category:West Virginia Senate": "تصنيف:مجلس شيوخ ولاية فرجينيا الغربية",
    "Category:West Virginia socialists": "تصنيف:أعضاء الحزب الاشتراكي في فرجينيا الغربية",
    "Category:West Virginia Unionists": "تصنيف:أعضاء الحزب الوحدوي في فرجينيا الغربية",
    "Category:Westmoreland County, Virginia": "تصنيف:مقاطعة ويستمورلاند (فرجينيا)",
    "Category:Winchester, Virginia": "تصنيف:وينشستر (فرجينيا)",
    "Category:Wirt County, West Virginia": "تصنيف:مقاطعة ويرت (فرجينيا الغربية)",
    "Category:Wise County, Virginia": "تصنيف:مقاطعة وايز (فرجينيا)",
    "Category:Women in West Virginia": "تصنيف:المرأة في فرجينيا الغربية",
    "Category:Women state legislators in West Virginia": "تصنيف:مشرعات الولايات في فرجينيا الغربية",
    "Category:Works set in West Virginia": "تصنيف:أعمال تقع أحداثها في فرجينيا الغربية",
    "Category:Wrestling in West Virginia": "تصنيف:المصارعة في فرجينيا الغربية",
    "Category:Writers from Alderson, West Virginia": "تصنيف:كتاب من ألدرسن (فرجينيا الغربية)",
    "Category:Writers from Alexandria, Virginia": "تصنيف:كتاب من الإسكندرية (فرجينيا)",
    "Category:Writers from Barbour County, West Virginia": "تصنيف:كتاب من مقاطعة بربور (فرجينيا الغربية)",
    "Category:Writers from Beckley, West Virginia": "تصنيف:كتاب من بيكلي (فرجينيا الغربية)",
    "Category:Writers from Berkeley County, West Virginia": "تصنيف:كتاب من مقاطعة بيركلي (فرجينيا الغربية)",
    "Category:Writers from Bluefield, West Virginia": "تصنيف:كتاب من بلوفيلد (فرجينيا الغربية)",
    "Category:Writers from Braxton County, West Virginia": "تصنيف:كتاب من مقاطعة براكستون (فرجينيا الغربية)",
    "Category:Writers from Brooke County, West Virginia": "تصنيف:كتاب من مقاطعة بروك (فرجينيا الغربية)",
    "Category:Writers from Cabell County, West Virginia": "تصنيف:كتاب من مقاطعة كابيل (فرجينيا الغربية)",
    "Category:Writers from Charleston, West Virginia": "تصنيف:كتاب من تشارلستون (فرجينيا الغربية)",
    "Category:Writers from Clarksburg, West Virginia": "تصنيف:كتاب من كلاركسبورغ (فرجينيا الغربية)",
    "Category:Writers from Fayette County, West Virginia": "تصنيف:كتاب من مقاطعة فيات (فرجينيا الغربية)",
    "Category:Writers from Greenbrier County, West Virginia": "تصنيف:كتاب من مقاطعة غرينبريه (فرجينيا الغربية)",
    "Category:Writers from Hampshire County, West Virginia": "تصنيف:كتاب من مقاطعة هامبشاير (فرجينيا الغربية)",
    "Category:Writers from Hardy County, West Virginia": "تصنيف:كتاب من مقاطعة هاردي (فرجينيا الغربية)",
    "Category:Writers from Harrison County, West Virginia": "تصنيف:كتاب من مقاطعة هاريسون (فرجينيا الغربية)",
    "Category:Writers from Jefferson County, West Virginia": "تصنيف:كتاب من مقاطعة جيفيرسون (فرجينيا الغربية)",
    "Category:Writers from Kanawha County, West Virginia": "تصنيف:كتاب من مقاطعة كاناوا (فرجينيا الغربية)",
    "Category:Writers from Lewis County, West Virginia": "تصنيف:كتاب من مقاطعة لويس (فرجينيا الغربية)",
    "Category:Writers from Marshall County, West Virginia": "تصنيف:كتاب من مقاطعة مارشال (فرجينيا الغربية)",
    "Category:Writers from Martinsburg, West Virginia": "تصنيف:كتاب من مرتينسبورغ (فرجينيا الغربية)",
    "Category:Writers from Mason County, West Virginia": "تصنيف:كتاب من مقاطعة ماسون (فرجينيا الغربية)",
    "Category:Writers from McDowell County, West Virginia": "تصنيف:كتاب من مقاطعة مكداويل (فرجينيا الغربية)",
    "Category:Writers from Mercer County, West Virginia": "تصنيف:كتاب من مقاطعة ميرسير (فرجينيا الغربية)",
    "Category:Writers from Monongalia County, West Virginia": "تصنيف:كتاب من مقاطعة مونونغاليا (فرجينيا الغربية)",
    "Category:Writers from Morgan County, West Virginia": "تصنيف:كتاب من مقاطعة مورغان (فرجينيا الغربية)",
    "Category:Writers from Ohio County, West Virginia": "تصنيف:كتاب من مقاطعة أوهايو (فرجينيا الغربية)",
    "Category:Writers from Parkersburg, West Virginia": "تصنيف:كتاب من باركرسبورغ (فرجينيا الغربية)",
    "Category:Writers from Pendleton County, West Virginia": "تصنيف:كتاب من مقاطعة بيندلتون (فرجينيا الغربية)",
    "Category:Writers from Pocahontas County, West Virginia": "تصنيف:كتاب من مقاطعة بوكاهونتس (فرجينيا الغربية)",
    "Category:Writers from Preston County, West Virginia": "تصنيف:كتاب من مقاطعة بريستون (فرجينيا الغربية)",
    "Category:Writers from Raleigh County, West Virginia": "تصنيف:كتاب من مقاطعة رالي (فرجينيا الغربية)",
    "Category:Writers from Romney, West Virginia": "تصنيف:كتاب من رومني (فرجينيا الغربية)",
    "Category:Writers from Taylor County, West Virginia": "تصنيف:كتاب من مقاطعة تايلور (فرجينيا الغربية)",
    "Category:Writers from Tucker County, West Virginia": "تصنيف:كتاب من مقاطعة تاكر (فرجينيا الغربية)",
    "Category:Writers from Upshur County, West Virginia": "تصنيف:كتاب من مقاطعة أبشور (فرجينيا الغربية)",
    "Category:Writers from Wayne County, West Virginia": "تصنيف:كتاب من مقاطعة وين (فرجينيا الغربية)",
    "Category:Writers from West Virginia by county": "تصنيف:كتاب من فرجينيا الغربية حسب المقاطعة",
    "Category:Writers from Wetzel County, West Virginia": "تصنيف:كتاب من مقاطعة ويتزل (فرجينيا الغربية)",
    "Category:Writers from Wheeling, West Virginia": "تصنيف:كتاب من ويلينغ (فرجينيا الغربية)",
    "Category:Writers from Wirt County, West Virginia": "تصنيف:كتاب من مقاطعة ويرت (فرجينيا الغربية)",
    "Category:Writers from Wood County, West Virginia": "تصنيف:كتاب من مقاطعة وود (فرجينيا الغربية)",
    "Category:Wyoming County, West Virginia": "تصنيف:مقاطعة وايومنغ (فرجينيا الغربية)",
    "Category:Wythe County, Virginia": "تصنيف:مقاطعة وايذ (فرجينيا)",
    "Category:Years of the 19th century in West Virginia": "تصنيف:سنوات القرن 19 في فرجينيا الغربية",
    "Category:York County, Virginia": "تصنيف:مقاطعة يورك (فرجينيا)",
}

to_test = [
    ("test_virginia_1", data_virginia_1),
    ("test_virginia_2", data_virginia_2),
]


@pytest.mark.parametrize("category, expected", data_virginia_1.items(), ids=data_virginia_1.keys())
@pytest.mark.fast
def test_virginia_1(category: str, expected: str) -> None:
    label = resolve_arabic_category_label(category)
    assert label == expected


@pytest.mark.parametrize("name,data", to_test)
@pytest.mark.dump
def test_dump_all(name: str, data: dict[str, str]) -> None:
    expected, diff_result = one_dump_test(data, resolve_arabic_category_label)

    dump_diff(diff_result, name)
    assert diff_result == expected, f"Differences found: {len(diff_result):,}, len all :{len(data):,}"



import sys
from pathlib import Path

if _Dir := Path(__file__).parent.parent:
    sys.path.append(str(_Dir))

from ArWikiCats import logger, resolve_arabic_category_label
from ArWikiCats.genders_resolvers.nat_genders_pattern_multi import resolve_nat_genders_pattern_v2
from ArWikiCats.legacy_bots.ma_bots2.year_or_typeo import (
    label_for_startwith_year_or_typeo,
)
from ArWikiCats.new.resolve_films_bots.resolve_films_labels import _get_films_key_tyty_new
from ArWikiCats.new.resolve_films_bots.resolve_films_labels_and_time import get_films_key_tyty_new_and_time
from ArWikiCats.new_resolvers.jobs_resolvers.mens import mens_resolver_labels
from ArWikiCats.new_resolvers.nationalities_resolvers.nationalities_v2 import resolve_by_nats
from ArWikiCats.new_resolvers.relations_resolver.nationalities_double_v2 import resolve_by_nats_double_v2
from ArWikiCats.new_resolvers.sports_resolvers.jobs_multi_sports_reslover import jobs_in_multi_sports

logger.set_level("DEBUG")

# print(resolve_arabic_category_label("Category:2015 American television"))

# print(resolve_nat_genders_pattern_v2("classical composers"))
# print(resolve_nat_genders_pattern_v2("guitarists"))
# print(resolve_nat_genders_pattern_v2("male guitarists"))
# print(resolve_nat_genders_pattern_v2("yemeni male guitarists"))
# print(resolve_nat_genders_pattern_v2("male yemeni guitarists"))
# print(get_films_key_tyty_new_and_time("american adult animated television films"))
# print(get_films_key_tyty_new_and_time("1960s yemeni comedy films"))
# print("-----"*20)
# print(label_for_startwith_year_or_typeo("1960s yemeni comedy films"))
# print(_get_films_key_tyty_new("animated short film films"))
# print(_get_films_key_tyty_new("American war films"))
# print(_get_films_key_tyty_new("animated short films"))
# print(get_films_key_tyty_new_and_time("2017 American television series debuts"))
# print(resolve_by_nats("Jewish history"))
# print(resolve_by_nats("American history"))
# print(resolve_by_nats("Jewish-American history"))
# print(mens_resolver_labels("men writers"))
# print(jobs_in_multi_sports("paralympic sailors"))
print(resolve_by_nats_double_v2("jewish german surnames"))
# print(resolve_by_nats_double_v2("jewish history"))

# python3 D:/categories_bot/make2_new/examples/run.py
# python3 -c "from ArWikiCats import resolve_arabic_category_label; print(resolve_arabic_category_label('Category:2015 American television'))"



#!/usr/bin/python3
"""

from ..matables_bots.check_bot import check_key_new_players
check_key_new_players(key)
"""

import pytest

from ArWikiCats.legacy_bots.matables_bots.check_bot import check_key_new_players


@pytest.mark.fast
def test_1() -> None:
    result = check_key_new_players("actors")
    assert result is True
